@@ -58,7 +58,7 @@ class CacheableMarkup extends XmlContent {
             } else {
                 // user our php lib. TESTME
                 include_once("ziplib.php");
-                $zip = ZipReader($packed);
+                $zip = new ZipReader($packed);
                 list(,$data,$attrib) = $zip->readFile();
                 return unserialize($data);
             }
@@ -301,6 +301,7 @@ class Cached_WikiLink extends Cached_Link {
             $this->_anchor = $anchor;
         if ($label and $label != $page)
             $this->_label = $label;
+        $this->_basepage = false;
     }
 
     function _getType() {
@@ -329,6 +330,7 @@ class Cached_WikiLink extends Cached_Link {
     }
 
     function expand($basepage, &$markup) {
+        $this->_basepage = $basepage;
 	$label = isset($this->_label) ? $this->_label : false;
 	$anchor = isset($this->_anchor) ? (string)$this->_anchor : '';
         $page = new WikiPageName($this->_page, $basepage, $anchor);
@@ -336,12 +338,13 @@ class Cached_WikiLink extends Cached_Link {
 	else return HTML($label);
     }
 
-    function asXml() {
+    function asXML() {
 	$label = isset($this->_label) ? $this->_label : false;
 	$anchor = isset($this->_anchor) ? (string)$this->_anchor : '';
-        $page = new WikiPageName($this->_page, false, $anchor);
+        // need basepage for subpages like /Remove (within CreateTOC)
+        $page = new WikiPageName($this->_page, $this->_basepage, $anchor);
 	$link = WikiLink($page, 'auto', $label);
-        return $link->asXml();
+        return $link->asXML();
     }
 
     function asString() {
@@ -379,10 +382,10 @@ class Cached_PhpwikiURL extends Cached_DynamicContent
         return LinkPhpwikiURL($this->_url, $label, $basepage);
     }
 
-    function asXml() {
+    function asXML() {
         $label = isset($this->_label) ? $this->_label : false;
         $link = LinkPhpwikiURL($this->_url, $label);
-        return $link->asXml();
+        return $link->asXML();
     }
 
     function asString() {
@@ -496,7 +499,7 @@ class Cached_PluginInvocation extends Cached_DynamicContent {
     }
 
     function expand($basepage, &$markup) {
-        $loader = &$this->_getLoader();
+        $loader = $this->_getLoader();
 
         $xml = $loader->expandPI($this->_pi, $GLOBALS['request'], $markup, $basepage);
         $div = HTML::div(array('class' => 'plugin'));
@@ -526,12 +529,12 @@ class Cached_PluginInvocation extends Cached_DynamicContent {
 
 
     function getWikiPageLinks($basepage) {
-        $loader = &$this->_getLoader();
+        $loader = $this->_getLoader();
 
         return $loader->getWikiPageLinks($this->_pi, $basepage);
     }
 
-    function _getLoader() {
+    function & _getLoader() {
         static $loader = false;
 
 	if (!$loader) {
