@@ -212,6 +212,13 @@ class ErrorManager
             $msg->printXML();
             return;
         }
+
+        // template which flushed the pending errors already handled,
+        // so display now all errors directly.
+        if (!empty($GLOBALS['request']->_finishing)) {
+            $this->_postpone_mask = 0;
+	}
+        
         $in_handler = true;
 
         foreach ($this->_handlers as $handler) {
@@ -239,11 +246,10 @@ class ErrorManager
             }
         }
 
-        $this->_noCacheHeaders();
-
         // Error was either fatal, or was not handled by a handler.
         // Handle it ourself.
         if ($error->isFatal()) {
+            $this->_noCacheHeaders();
             echo "<html><body><div style=\"font-weight:bold; color:red\">Fatal Error:</div>\n";
             if (defined('DEBUG') and (DEBUG & _DEBUG_TRACE)) {
                 echo "error_reporting=",error_reporting(),"\n<br>";
@@ -254,8 +260,8 @@ class ErrorManager
         }
         else if (($error->errno & error_reporting()) != 0) {
             if  (($error->errno & $this->_postpone_mask) != 0) {
-                if ((function_exists('is_a') and is_a($error,'PhpErrorOnce'))
-                    or (!function_exists('is_a') and 
+                if ((function_exists('isa') and isa($error, 'PhpErrorOnce'))
+                    or (!function_exists('isa') and 
                     (
                      // stdlib independent isa()
                      (strtolower(get_class($error)) == 'phperroronce')
@@ -269,6 +275,7 @@ class ErrorManager
             }
             else {
                 //echo "postponed errors: ";
+                $this->_noCacheHeaders();
                 if (defined('DEBUG') and (DEBUG & _DEBUG_TRACE)) {
                     echo "error_reporting=",error_reporting(),"\n";
                     if (function_exists("debug_backtrace")) // >= 4.3.0
@@ -610,6 +617,12 @@ if (!isset($GLOBALS['ErrorManager'])) {
 }
 
 // $Log: ErrorManager.php,v $
+// Revision 1.45  2005/10/29 14:28:08  uckelman
+// existence of isa should be checked, not built-in is_a()
+//
+// Revision 1.44  2005/08/07 10:52:43  rurban
+// stricter error handling: dba errors are fatal, display errors on Request->finish or session_close
+//
 // Revision 1.43  2005/04/11 19:41:23  rurban
 // Improve postponed errors+warnins list layout.
 //
