@@ -141,6 +141,7 @@ function IniConfig($file) {
          'ALLOWED_PROTOCOLS', 'INLINE_IMAGES', 'SUBPAGE_SEPARATOR', /*'KEYWORDS',*/
          // extra logic:
          //'DATABASE_PREFIX', 'DATABASE_DSN', 'DATABASE_TYPE', 'DATABASE_DBHANDLER',
+	 'DATABASE_OPTIMISE_FREQUENCY',
          'INTERWIKI_MAP_FILE', 'COPYRIGHTPAGE_TITLE', 'COPYRIGHTPAGE_URL',
          'AUTHORPAGE_TITLE', 'AUTHORPAGE_URL', 
          'WIKI_NAME_REGEXP',
@@ -183,7 +184,8 @@ function IniConfig($file) {
          'DISABLE_HTTP_REDIRECT',
          'PLUGIN_CACHED_USECACHE', 'PLUGIN_CACHED_FORCE_SYNCMAP',
          'BLOG_EMPTY_DEFAULT_PREFIX', 'DATABASE_PERSISTENT',
-         'ENABLE_DISCUSSION_LINK', 'ENABLE_CAPTCHA'
+         'ENABLE_DISCUSSION_LINK', 'ENABLE_CAPTCHA',
+         'USE_CAPTCHA_RANDOM_WORD'
          );
 
     $rs = @parse_ini_file($file);
@@ -245,7 +247,9 @@ function IniConfig($file) {
                                   'ALLOW_HTTP_AUTH_LOGIN', 'ALLOW_LDAP_LOGIN',
                                   'ALLOW_IMAP_LOGIN', 'ALLOW_USER_LOGIN',
                                   'REQUIRE_SIGNIN_BEFORE_EDIT',
-                                  'WIKIDB_NOCACHE_MARKUP')))
+                                  'WIKIDB_NOCACHE_MARKUP',
+                                  'COMPRESS_OUTPUT'
+                                  )))
         {
             ;
         }
@@ -290,7 +294,7 @@ function IniConfig($file) {
             unset($rsdef[$item]);
         }
     }
-    if (!in_array(DATABASE_TYPE, array('SQL','ADODB','PDO','dba','file','cvs','cvsclient')))
+    if (!in_array(DATABASE_TYPE, array('SQL','ADODB','PDO','dba','file','cvs')))
         trigger_error(sprintf("Invalid DATABASE_TYPE=%s. Choose one of %s", 
                               DATABASE_TYPE, "SQL,ADODB,PDO,dba,file,cvs"), 
                       E_USER_ERROR);
@@ -361,6 +365,7 @@ function IniConfig($file) {
                       'DBAUTH_AUTH_UPDATE' => 'auth_update',
                       'DBAUTH_AUTH_CREATE' => 'auth_create',
                       'DBAUTH_PREF_SELECT' => 'pref_select',
+                      'DBAUTH_PREF_INSERT' => 'pref_insert',
                       'DBAUTH_PREF_UPDATE' => 'pref_update',
                       'DBAUTH_IS_MEMBER' => 'is_member',
                       'DBAUTH_GROUP_MEMBERS' => 'group_members',
@@ -506,9 +511,8 @@ function IniConfig($file) {
 
 // moved from lib/config.php [1ms]
 function fixup_static_configs($file) {
-    global $FieldSeparator, $charset, $WikiNameRegexp, $KeywordLinkRegexp, $AllActionPages;
+    global $FieldSeparator, $charset, $WikiNameRegexp, $AllActionPages;
     global $HTTP_SERVER_VARS, $DBParams, $LANG;
-
     // init FileFinder to add proper include paths
     FindFile("lib/interwiki.map",true);
     
@@ -655,7 +659,7 @@ function fixup_static_configs($file) {
  * by startup scripts for wiki farms.
  */
 function fixup_dynamic_configs($file) {
-    global $WikiNameRegexp, $KeywordLinkRegexp;
+    global $WikiNameRegexp;
     global $HTTP_SERVER_VARS, $DBParams, $LANG;
 
     if (defined('INCLUDE_PATH') and INCLUDE_PATH)
@@ -667,16 +671,22 @@ function fixup_dynamic_configs($file) {
 
     update_locale(isset($LANG) ? $LANG : DEFAULT_LANGUAGE);
     if (empty($LANG)) {
-        if (!defined("DEFAULT_LANGUAGE") or !DEFAULT_LANGUAGE)
+        if (!defined("DEFAULT_LANGUAGE") or !DEFAULT_LANGUAGE) {
             // TODO: defer this to WikiRequest::initializeLang()
             $LANG = guessing_lang(); 
-        else    
+            guessing_setlocale (LC_ALL,$LANG);
+        }
+        else
             $LANG = DEFAULT_LANGUAGE;
     }
  
     // Set up (possibly fake) gettext()
     // Todo: this could be moved to fixup_static_configs()
-    if (!function_exists ('bindtextdomain')) {
+    // Bug #1381464 with php-5.1.1
+    if (!function_exists ('bindtextdomain')
+        and !function_exists ('gettext')
+        and !function_exists ('_'))
+    {
         $locale = array();
 
         function gettext ($text) { 
@@ -685,7 +695,6 @@ function fixup_dynamic_configs($file) {
                 return $locale[$text];
             return $text;
         }
-
         function _ ($text) {
             return gettext($text);
         }
@@ -707,6 +716,9 @@ function fixup_dynamic_configs($file) {
             $chback = 1;
             $bindtextdomain_real = @bindtextdomain("phpwiki", $bindtextdomain_path);
         }
+        // tell gettext not to use unicode. PHP >= 4.2.0. Thanks to Kai Krakow.
+        if (defined('CHARSET') and function_exists('bind_textdomain_codeset'))
+            @bind_textdomain_codeset("phpwiki", CHARSET);
         textdomain("phpwiki");
         if ($chback) { // change back
             chdir($bindtextdomain_real . (isWindows() ? "\\.." : "/.."));
@@ -715,8 +727,7 @@ function fixup_dynamic_configs($file) {
 
     // language dependent updates:
     $WikiNameRegexp = pcre_fix_posix_classes($WikiNameRegexp);
-    if ($KeywordLinkRegexp)
-    	$KeywordLinkRegexp = pcre_fix_posix_classes($KeywordLinkRegexp);
+    //if ($KeywordLinkRegexp) $KeywordLinkRegexp = pcre_fix_posix_classes($KeywordLinkRegexp);
     if (!defined('CATEGORY_GROUP_PAGE'))
         define('CATEGORY_GROUP_PAGE',_("CategoryGroup"));
     if (!defined('WIKI_NAME'))
@@ -850,6 +861,12 @@ function fixup_dynamic_configs($file) {
 }
 
 // $Log: IniConfig.php,v $
+// Revision 1.97  2005/10/29 14:16:38  rurban
+// fix broken locale update
+//
+// Revision 1.96  2005/09/26 06:27:33  rurban
+// default locale fix Thomas Harding
+//
 // Revision 1.94  2005/09/15 05:56:12  rurban
 // read configurator desc from config-dist.ini, update desc, fix some warnings
 //
