@@ -1,5 +1,5 @@
 <?php 
-rcs_id('$Id: InlineParser.php,v 1.69 2005/09/14 05:57:19 rurban Exp $');
+rcs_id('$Id: InlineParser.php,v 1.70 2005/10/31 16:45:23 rurban Exp $');
 /* Copyright (C) 2002 Geoffrey T. Dairiki <dairiki@dairiki.org>
  * Copyright (C) 2004,2005 Reini Urban
  *
@@ -356,6 +356,17 @@ function LinkBracketLink($bracketlink) {
     } else
         $link  = UnWikiEscape($rawlink);
 
+    /* Relatives links by Joel Schaubert.
+     * Recognize [../bla] or [/bla] as relative links, without needing http://
+     * but {/link] only if SUBPAG_SEPERATOR is not /
+     */
+    if (SUBPAGE_SEPARATOR == '/') {
+    	if (preg_match('/^\.\.\//', $link)) {
+            return new Cached_ExternalLink($link, $label);
+    	}
+    } else if (preg_match('/^(\.\.\/|\/)/', $link)) {
+        return new Cached_ExternalLink($link, $label);
+    }
     // [label|link]
     // if label looks like a url to an image, we want an image link.
     if (isImageLink($label)) {
@@ -726,20 +737,23 @@ class InlineTransformer
     var $_markup = array();
     
     function InlineTransformer ($markup_types = false) {
-        if (!$markup_types)
+        if (!$markup_types) {
+            $non_default = false;
             $markup_types = array('escape', 'bracketlink', 'url',
                                   'interwiki', 'wikiword', 'linebreak',
                                   'old_emphasis', 'nestled_emphasis',
                                   'html_emphasis', 'html_abbr', 'plugin',
                                   'isonumchars', 'isohexchars', /*'html_entities',*/
                                   );
+        } else 
+            $non_default = true;
         foreach ($markup_types as $mtype) {
             $class = "Markup_$mtype";
             $this->_addMarkup(new $class);
         }
-        if (ENABLE_MARKUP_COLOR)
+        if (ENABLE_MARKUP_COLOR and !$non_default)
             $this->_addMarkup(new Markup_color);
-        if (defined("ENABLE_MARKUP_TEMPLATE") and ENABLE_MARKUP_TEMPLATE)
+        if (ENABLE_MARKUP_TEMPLATE and !$non_default)
             $this->_addMarkup(new Markup_template_plugin);
     }
 
@@ -870,6 +884,9 @@ function TransformLinks($text, $markup = 2.0, $basepage = false) {
 }
 
 // $Log: InlineParser.php,v $
+// Revision 1.70  2005/10/31 16:45:23  rurban
+// added cfg-able markups only for default TextTransformation, not for links and others
+//
 // Revision 1.69  2005/09/14 05:57:19  rurban
 // make ENABLE_MARKUP_TEMPLATE optional
 //
