@@ -1,5 +1,5 @@
 <?php // -*-php-*-
-rcs_id('$Id: Request.php,v 1.97 2005/09/14 05:58:17 rurban Exp $');
+rcs_id('$Id: Request.php,v 1.105 2006/04/17 17:25:19 rurban Exp $');
 /*
  Copyright (C) 2002,2004,2005 $ThePhpWikiProgrammingTeam
  
@@ -251,7 +251,7 @@ class Request {
         $validators = &$this->_validators;
         
         // Set validator headers
-        if ($this->_is_buffering_output or !headers_sent()) {
+        if (!empty($this->_is_buffering_output) or !headers_sent()) {
             if (($etag = $validators->getETag()) !== false)
                 header("ETag: " . $etag->asString());
             if (($mtime = $validators->getModificationTime()) !== false)
@@ -269,7 +269,7 @@ class Request {
         if ($status) {
             // Return short response due to failed conditionals
             $this->setStatus($status);
-            print "\n\n";
+            echo "\n\n";
             $this->discardOutput();
             $this->finish();
             exit();
@@ -336,6 +336,7 @@ class Request {
             
         if ($this->getArg('start_debug'))
             $compress = false;
+        
         // Should we compress even when apache_note is not available?
         // sf.net bug #933183 and http://bugs.php.net/17557
         // This effectively eliminates CGI, but all other servers also. hmm.
@@ -343,7 +344,9 @@ class Request {
             and (!function_exists('ob_gzhandler') 
                  or !function_exists('apache_note'))) 
             $compress = false;
-        // http://www.php.net/ob_gzhandler "output handler 'ob_gzhandler' cannot be used twice"
+            
+        // "output handler 'ob_gzhandler' cannot be used twice"
+        // http://www.php.net/ob_gzhandler
         if ($compress and ini_get("zlib.output_compression"))
             $compress = false;
 
@@ -365,7 +368,11 @@ class Request {
             $compress = false;
 
         if ($compress) {
-            ob_start('ob_gzhandler');
+            ob_start('phpwiki_gzhandler');
+            
+            // TODO: dont send a length or get the gzip'ed data length.
+            $this->_is_compressing_output = true; 
+            header("Content-Encoding: gzip");
             /*
              * Attempt to prevent Apache from doing the dreaded double-gzip.
              *
@@ -382,6 +389,7 @@ class Request {
             // at any point.
             // FIXME: change the name of this method.
             ob_start();
+            $this->_is_compressing_output = false;
         }
         $this->_is_buffering_output = true;
         $this->_ob_get_length = 0;
@@ -419,13 +427,13 @@ class Request {
     	$this->_finishing = true;
         if (!empty($this->_accesslog)) {
             $this->_accesslog->push($this);
-            if (empty($this->_do_chunked_output))
+            if (empty($this->_do_chunked_output) and empty($this->_ob_get_length))
                 $this->_ob_get_length = ob_get_length();
             $this->_accesslog->setSize($this->_ob_get_length);
             global $RUNTIMER;
             if ($RUNTIMER) $this->_accesslog->setDuration($RUNTIMER->getTime());
             // sql logging must be done before the db is closed.
-            if ($this->_accesslog->logtable)
+            if (isset($this->_accesslog->logtable))
                 $this->_accesslog->write_sql();
         }
         
@@ -441,16 +449,22 @@ class Request {
                 echo $html;
             } else {
             */
-	    if (!headers_sent()) {
-		if (empty($this->_do_chunked_output)) {
-		    $this->_ob_get_length = ob_get_length();
-		}
-		header(sprintf("Content-Length: %d", $this->_ob_get_length));
+            // if _is_compressing_output then ob_get_length() returns 
+            // the uncompressed length, not the gzip'ed as required.
+	    if (!headers_sent() and !$this->_is_compressing_output) {
+                // php url-rewriting miscalculates the ob length. fixes bug #1376007
+                if (ini_get('use_trans_sid') == 'off') {
+                    if (empty($this->_do_chunked_output)) {
+                        $this->_ob_get_length = ob_get_length();
+                    }
+                    header(sprintf("Content-Length: %d", $this->_ob_get_length));
+                }
             }
             $this->_is_buffering_output = false;
-	}
-
-        while (@ob_end_flush()); // hmm. there's some error in redirect
+            ob_end_flush();
+	} elseif (function_exists('ob_get_level') and @ob_get_level()) {
+            ob_end_flush();
+        }
         session_write_close();
         if (!empty($this->_dbi)) {
             $this->_dbi->close();
@@ -617,7 +631,7 @@ class Request_CookieVars {
 
     function set($key, $val, $persist_days = false, $path = false) {
     	// if already defined, ignore
-    	if (defined('MAIN_setUser') and $key = 'WIKI_ID') return;
+    	if (defined('MAIN_setUser') and $key = getCookieName()) return;
         if (defined('WIKI_XMLRPC') and WIKI_XMLRPC) return;
 
         $vars = &$GLOBALS['HTTP_COOKIE_VARS'];
@@ -1158,7 +1172,7 @@ function Request_AccessLogEntry_shutdown_function () {
 
 class HTTP_ETag {
     function HTTP_ETag($val, $is_weak=false) {
-        $this->_val = hash($val);
+        $this->_val = wikihash($val);
         $this->_weak = $is_weak;
     }
 
@@ -1336,6 +1350,34 @@ class HTTP_ValidatorSet {
 
 
 // $Log: Request.php,v $
+// Revision 1.105  2006/04/17 17:25:19  rurban
+// make the flush error go away. die
+//
+// Revision 1.104  2006/04/16 11:42:16  rurban
+// php url-rewriting miscalculates the ob length. fixes bug #1376007
+//
+// do not flush a not existing buffer to avoid Pragma: no-cache on @ error.
+// fixes bug #1438448
+//
+// Revision 1.103  2006/04/15 12:23:32  rurban
+// silence $this->_is_buffering_output warning
+//
+// Revision 1.102  2006/03/19 15:01:00  rurban
+// sf.net patch #1333957 by Matt Brown: Authentication cookie identical across all wikis on a host
+//
+// Revision 1.101  2006/03/07 20:45:43  rurban
+// wikihash for php-5.1
+//
+// Revision 1.100  2006/01/17 18:57:09  uckelman
+// _accesslog->logtable is not set when using non-SQL logging; check should
+//  be isset to avoid a PHP warning
+//
+// Revision 1.99  2005/09/18 16:01:09  rurban
+// trick to send the correct gzipped Content-Length
+//
+// Revision 1.98  2005/09/18 15:15:53  rurban
+// add a proper Content-Encoding: gzip if compressed, and omit Content-Length then.
+//
 // Revision 1.97  2005/09/14 05:58:17  rurban
 // protect against Content-Length if headers_sent(), fixed writing unwanted accesslog sql entries
 //
@@ -1618,4 +1660,4 @@ class HTTP_ValidatorSet {
 // c-hanging-comment-ender-p: nil
 // indent-tabs-mode: nil
 // End:   
-?>
\ No newline at end of file
+?>
