@@ -185,7 +185,7 @@ class TextSearchQuery {
                 $subclauses[] = "(" . $this->_sql_clause($leaf) . ")";
             return join(" $node->op ", $subclauses);
         default:
-            assert($node->op == VOID);
+            assert($node->op == 'VOID');
             return '1=1';
         }
     }
@@ -319,7 +319,7 @@ extends TextSearchQuery_node
     function regexp() {
         return '(?=.*' . preg_quote($this->word, '/') . ')';
     }
-    function highlight_words($negated = false) {
+    function highlight_words ($negated = false) {
         return $negated ? array() : array($this->word);
     }
     function _sql_quote() {
@@ -339,28 +339,28 @@ class TextSearchQuery_node_starts_with
 extends TextSearchQuery_node_word {
     var $op = "STARTS_WITH";
     function regexp() { return '(?=.*\b' . preg_quote($this->word, '/') . ')'; }
-    function sql()    { return $this->_sql_quote($this->word).'%'; }
+    function sql ()   { return $this->_sql_quote($this->word).'%'; }
 }
 
 class TextSearchQuery_node_ends_with
 extends TextSearchQuery_node_word {
     var $op = "ENDS_WITH";
     function regexp() { return '(?=.*' . preg_quote($this->word, '/') . '\b)'; }
-    function sql()    { return '%'.$this->_sql_quote($this->word); }
+    function sql ()   { return '%'.$this->_sql_quote($this->word); }
 }
 
 class TextSearchQuery_node_exact
 extends TextSearchQuery_node_word {
     var $op = "EXACT";
     function regexp() { return '(?=\b' . preg_quote($this->word, '/') . '\b)'; }
-    function sql()    { return $this->_sql_squote($this->word); }
+    function sql ()   { return $this->_sql_squote($this->word); }
 }
 
 class TextSearchQuery_node_regex // posix regex. FIXME!
 extends TextSearchQuery_node_word {
     var $op = "REGEX"; // using REGEXP or ~ extension
     function regexp() { return '(?=.*\b' . $this->word . '\b)'; }
-    function sql()    { return $this->_sql_quote($this->word); }
+    function sql ()   { return $this->_sql_quote($this->word); }
 }
 
 class TextSearchQuery_node_regex_glob
@@ -407,7 +407,7 @@ extends TextSearchQuery_node
         return '(?!' . $leaf->regexp() . ')';
     }
 
-    function highlight_words($negated = false) {
+    function highlight_words ($negated = false) {
         return $this->leaves[0]->highlight_words(!$negated);
     }
 }
