@@ -199,14 +199,15 @@ class Theme {
         $this->_path  = defined('PHPWIKI_DIR') ? NormalizeLocalFileName("") : "";
         $this->_theme = "themes/$theme_name";
 
-        // by pixels
-        if ($GLOBALS['request']->getPref('doubleClickEdit')
-            or ENABLE_DOUBLECLICKEDIT)
-            $this->initDoubleClickEdit();
-
         if ($theme_name != 'default')
             $this->_default_theme = new Theme;
 
+        // by pixels
+        if ((is_object($GLOBALS['request']) // guard against unittests
+             and $GLOBALS['request']->getPref('doubleClickEdit'))
+            or ENABLE_DOUBLECLICKEDIT)
+            $this->initDoubleClickEdit();
+
         // will be replaced by acDropDown
         if (ENABLE_LIVESEARCH) { // by bitflux.ch
             $this->initLiveSearch();
@@ -1095,7 +1096,7 @@ class Theme {
 
     var $_MoreHeaders = array();
     function addMoreHeaders ($element) {
-        array_push($this->_MoreHeaders,$element);
+        array_push($this->_MoreHeaders, $element);
     }
     function getMoreHeaders () {
         if (empty($this->_MoreHeaders))
@@ -1176,8 +1177,8 @@ class Theme {
             $this->addMoreAttr('body', 'DoubleClickEdit', HTML::Raw(" ondblclick=\"url = document.URL; url2 = url; if (url.indexOf('?') != -1) url2 = url.slice(0, url.indexOf('?')); if ((url.indexOf('action') == -1) || (url.indexOf('action=browse') != -1)) document.location = url2 + '?action=edit';\""));
     }
 
-    // Immediate title search results via XMLHttpRequest
-    // by Bitflux GmbH, bitflux.ch. You need to install the livesearch.js seperately
+    // Immediate title search results via XMLHTML(HttpRequest
+    // by Bitflux GmbH, bitflux.ch. You need to install the livesearch.js seperately.
     // Google's or acdropdown is better.
     function initLiveSearch() {
         if (!$this->HTML_DUMP_SUFFIX) {
@@ -1442,6 +1443,9 @@ function listAvailableLanguages() {
 }
 
 // $Log: Theme.php,v $
+// Revision 1.132  2005/07/24 09:51:22  rurban
+// guard doubleClickEdit for unittests
+//
 // Revision 1.131  2005/06/10 06:09:06  rurban
 // enable getPref('doubleClickEdit')
 //
