@@ -220,20 +220,24 @@ class WikiDB {
         if (! $this->isWikiPage($pagename) and !isa($GLOBALS['request'],'MockRequest')) {
             $notify = $this->get('notify');
             if (!empty($notify) and is_array($notify)) {
+                global $request;
                 //TODO: deferr it (quite a massive load if you remove some pages).
                 //TODO: notification class which catches all changes,
-                //  and decides at the end of the request what to mail. (type, page, who, what, users, emails)
+                //  and decides at the end of the request what to mail. 
+                //  (type, page, who, what, users, emails)
                 // could be used for PageModeration and RSS2 Cloud xml-rpc also.
                 $page = new WikiDB_Page($this, $pagename);
                 list($emails, $userids) = $page->getPageChangeEmails($notify);
                 if (!empty($emails)) {
-                    $editedby = sprintf(_("Removed by: %s"), $GLOBALS['request']->_user->getId()); // Todo: host_id
+                    $from = $request->_user->getId() . '@' .  $request->get('REMOTE_HOST');
+                    $editedby = sprintf(_("Removed by: %s"), $from);
                     $emails = join(',', $emails);
                     $subject = sprintf(_("Page removed %s"), urlencode($pagename));
-                    if (mail($emails,"[".WIKI_NAME."] ".$subject, 
+                    if (mail("<undisclosed-recipients>","[".WIKI_NAME."] ".$subject, 
                              $subject."\n".
                              $editedby."\n\n".
-                             "Deleted $pagename"))
+                             "Deleted $pagename",
+                             "From: $from\r\nBcc: $emails"))
                         trigger_error(sprintf(_("PageChange Notification of %s sent to %s"),
                                               $pagename, join(',',$userids)), E_USER_NOTICE);
                     else
@@ -359,7 +363,9 @@ class WikiDB {
         $result = $this->_backend->text_search($search, true, $sortby, $limit, $exclude);
         return new WikiDB_PageIterator($this, $result,
                                        array('exclude' => $exclude,
-                                             'limit' => $limit));
+                                             'limit'   => $limit,
+                                             'stoplisted' => $result->stoplisted
+                                             ));
     }
 
     /**
@@ -651,8 +657,9 @@ class WikiDB_Page
                 trigger_error("empty pagename", E_USER_WARNING);
                 return false;
             }
-        } else 
+        } else {
             assert(is_string($pagename) and $pagename != '');
+        }
     }
 
     /**
@@ -895,10 +902,14 @@ class WikiDB_Page
 	// in the backend to control when to optimize.
         //
         // We're doing this here rather than in createRevision because
-        // postgres can't optimize while locked.
-        if ((DEBUG & _DEBUG_SQL) or (time() % 5 == 0)) {
-            if ($backend->optimize())
-                trigger_error(_("Optimizing database"), E_USER_NOTICE);
+        // postgresql can't optimize while locked.
+        if ((DEBUG & _DEBUG_SQL)
+	    or (DATABASE_OPTIMISE_FREQUENCY > 0 and 
+                (time() % DATABASE_OPTIMISE_FREQUENCY == 0))) {
+            if ($backend->optimize()) {
+                if (DEBUG)
+                    trigger_error(_("Optimizing database"), E_USER_NOTICE);
+            }
         }
 
         /* Generate notification emails? */
@@ -997,7 +1008,8 @@ class WikiDB_Page
         global $request;
         if (@is_array($request->_deferredPageChangeNotification)) {
             // collapse multiple changes (loaddir) into one email
-            $request->_deferredPageChangeNotification[] = array($this->_pagename, $emails, $userids);
+            $request->_deferredPageChangeNotification[] 
+		= array($this->_pagename, $emails, $userids);
             return;
         }
         $backend = &$this->_wikidb->_backend;
@@ -1032,13 +1044,13 @@ class WikiDB_Page
                 Iso8601DateTime($meta['mtime']) . "\n";
             $content .= _("New page");
         }
-        $editedby = sprintf(_("Edited by: %s"), $meta['author']);
+        $from = $request->_user->getId() . '@' .  $request->get('REMOTE_HOST');
+        $editedby = sprintf(_("Edited by: %s"), $from);
         $emails = join(',',$emails);
-        if (mail($emails,"[".WIKI_NAME."] ".$subject, 
-                 $subject."\n".
-                 $editedby."\n".
-                 $difflink."\n\n".
-                 $content))
+        if (mail("<undisclosed-recipients>",
+                 "[".WIKI_NAME."] ".$subject, 
+                 $subject."\n". $editedby."\n". $difflink."\n\n". $content,
+                 "From: $from\r\nBcc: $emails"))
             trigger_error(sprintf(_("PageChange Notification of %s sent to %s"),
                                   $this->_pagename, join(',',$userids)), E_USER_NOTICE);
         else
@@ -1054,21 +1066,21 @@ class WikiDB_Page
             $request->_deferredPageRenameNotification[] = array($this->_pagename, 
                                                                 $to, $meta, $emails, $userids);
         } else {
-            $from = $this->_pagename;
-            $editedby = sprintf(_("Edited by: %s"), $meta['author']) . ' ' . $meta['author_id'];
+            $oldname = $this->_pagename;
+            $from = $request->_user->getId() . '@' .  $request->get('REMOTE_HOST');
+            $editedby = sprintf(_("Edited by: %s"), $from);
             $emails = join(',',$emails);
-            $subject = sprintf(_("Page rename %s to %s"), urlencode($from), urlencode($to));
+            $subject = sprintf(_("Page rename %s to %s"), urlencode($oldname), urlencode($to));
             $link = WikiURL($to, true);
-            if (mail($emails,"[".WIKI_NAME."] ".$subject, 
-                     $subject."\n".
-                     $editedby."\n".
-                     $link."\n\n".
-                     "Renamed $from to $to"))
+            if (mail("<undisclosed-recipients>",
+                     "[".WIKI_NAME."] ".$subject, 
+                     $subject."\n".$editedby."\n".$link."\n\n"."Renamed $from to $to",
+                     "From: $from\r\nBcc: $emails"))
                 trigger_error(sprintf(_("PageChange Notification of %s sent to %s"),
-                                      $from, join(',',$userids)), E_USER_NOTICE);
+                                      $oldname, join(',',$userids)), E_USER_NOTICE);
             else
                 trigger_error(sprintf(_("PageChange Notification Error: Couldn't send %s to %s"),
-                                      $from, join(',',$userids)), E_USER_WARNING);
+                                      $oldname, join(',',$userids)), E_USER_WARNING);
         }
     }
 
@@ -1079,7 +1091,7 @@ class WikiDB_Page
      *
      * @return WikiDB_PageRevision The current WikiDB_PageRevision object. 
      */
-    function getCurrentRevision($need_content = true) {
+    function getCurrentRevision ($need_content = true) {
         $backend = &$this->_wikidb->_backend;
         $cache = &$this->_wikidb->_cache;
         $pagename = &$this->_pagename;
@@ -1110,7 +1122,7 @@ class WikiDB_Page
      * false if the requested revision does not exist in the {@link WikiDB}.
      * Note that version zero of any page always exists.
      */
-    function getRevision($version, $need_content=true) {
+    function getRevision ($version, $need_content=true) {
         $cache = &$this->_wikidb->_cache;
         $pagename = &$this->_pagename;
         
@@ -1142,7 +1154,7 @@ class WikiDB_Page
      * unless $version is greater than zero, a revision (perhaps version zero,
      * the default revision) will always be found.
      */
-    function getRevisionBefore($version=false, $need_content=true) {
+    function getRevisionBefore ($version=false, $need_content=true) {
         $backend = &$this->_wikidb->_backend;
         $pagename = &$this->_pagename;
         if ($version === false)
@@ -1186,8 +1198,8 @@ class WikiDB_Page
      * @return WikiDB_PageIterator A WikiDB_PageIterator containing
      * all matching pages.
      */
-    function getLinks($reversed = true, $include_empty=false, $sortby=false, 
-                      $limit=false, $exclude=false) {
+    function getLinks ($reversed = true, $include_empty=false, $sortby=false, 
+                       $limit=false, $exclude=false) {
         $backend = &$this->_wikidb->_backend;
         $result =  $backend->get_links($this->_pagename, $reversed, 
                                        $include_empty, $sortby, $limit, $exclude);
@@ -1230,23 +1242,26 @@ class WikiDB_Page
     }
             
     /**
-     * Access WikiDB_Page meta-data.
+     * Access WikiDB_Page non version-specific meta-data.
      *
      * @access public
      *
      * @param string $key Which meta data to get.
      * Some reserved meta-data keys are:
      * <dl>
-     * <dt>'locked'<dd> Is page locked?
+     * <dt>'date'  <dd> Created as unixtime
+     * <dt>'locked'<dd> Is page locked? 'yes' or 'no'
      * <dt>'hits'  <dd> Page hit counter.
-     * <dt>'pref'  <dd> Users preferences, stored in homepages.
+     * <dt>'_cached_html' <dd> Transformed CachedMarkup object, serialized + optionally gzipped.
+     *                         In SQL stored now in an extra column.
+     * Optional data:
+     * <dt>'pref'  <dd> Users preferences, stored only in homepages.
      * <dt>'owner' <dd> Default: first author_id. We might add a group with a dot here:
      *                  E.g. "owner.users"
      * <dt>'perm'  <dd> Permission flag to authorize read/write/execution of 
      *                  page-headers and content.
+     + <dt>'moderation'<dd> ModeratedPage data
      * <dt>'score' <dd> Page score (not yet implement, do we need?)
-     * <dt>'_cached_html' <dd> Transformed CachedMarkup object, serialized + optionally gzipped.
-     *                         In SQL stored in an extra column.
      * </dl>
      *
      * @return scalar The requested value, or false if the requested data
@@ -1775,12 +1790,15 @@ class WikiDB_PageIterator
             return false;
 
         $pagename = &$next['pagename'];
+        if (!is_string($pagename)) { // Bug #1327912 fixed by Joachim Lous
+            $pagename = strval($pagename);
+        }
         if (!$pagename) {
             trigger_error('empty pagename in WikiDB_PageIterator::next()', E_USER_WARNING);
             var_dump($next);
             return false;
         }
-        // there's always hits, but we cache only if more 
+        // There's always hits, but we cache only if more 
         // (well not with file, cvs and dba)
         if (isset($next['pagedata']) and count($next['pagedata']) > 1) {
             $this->_wikidb->_cache->cache_data($next);
@@ -2190,6 +2208,15 @@ function _sql_debuglog_shutdown_function() {
 }
 
 // $Log: WikiDB.php,v $
+// fix bug #1327912 numeric pagenames can break plugins (Joachim Lous)
+// pass stoplist through iterator
+//
+// Revision 1.137  2005/10/12 06:16:18  rurban
+// better From header
+//
+// Revision 1.136  2005/10/03 16:14:57  rurban
+// improve description
+//
 // Revision 1.135  2005/09/11 14:19:44  rurban
 // enable LIMIT support for fulltext search
 //
