@@ -2,7 +2,7 @@
 rcs_id('$Id: ADODB.php,v 1.78 2005/09/14 06:04:43 rurban Exp $');
 
 /*
- Copyright 2002,2004 $ThePhpWikiProgrammingTeam
+ Copyright 2002,2004,2005,2006 $ThePhpWikiProgrammingTeam
 
  This file is part of PhpWiki.
 
@@ -26,7 +26,7 @@ rcs_id('$Id: ADODB.php,v 1.78 2005/09/14 06:04:43 rurban Exp $');
  * Based on PearDB.php. 
  * @author: Lawrence Akka, Reini Urban
  *
- * Now (phpwiki-1.3.10) with adodb-4.22, by Reini Urban:
+ * Now (since phpwiki-1.3.10) with adodb-4.22, by Reini Urban:
  * 1) Extended to use all available database backends, not only mysql.
  * 2) It uses the ultra-fast binary adodb extension if loaded.
  * 3) We use FETCH_NUM instead of FETCH_ASSOC (faster and more generic)
@@ -39,6 +39,8 @@ rcs_id('$Id: ADODB.php,v 1.78 2005/09/14 06:04:43 rurban Exp $');
  *
  * phpwiki-1.3.11, by Philippe Vanhaesendonck
  * - pass column list to iterators so we can FETCH_NUM in all cases
+ * phpwiki-1.3.12: get rid of ISNULL
+ * phpwiki-1.3.13: tsearch2 and stored procedures
  *
  * ADODB basic differences to PearDB: It pre-fetches the first row into fields, 
  * is dirtier in style, layout and more low-level ("worse is better").
@@ -107,7 +109,8 @@ extends WikiDB_backend
         $page_tbl = $this->_table_names['page_tbl'];
         $version_tbl = $this->_table_names['version_tbl'];
         $this->page_tbl_fields = "$page_tbl.id AS id, $page_tbl.pagename AS pagename, "
-            . "$page_tbl.hits hits";
+            . "$page_tbl.hits AS hits";
+        $this->links_field_list = array('id', 'pagename');
         $this->page_tbl_field_list = array('id', 'pagename', 'hits');
         $this->version_tbl_fields = "$version_tbl.version AS version, "
             . "$version_tbl.mtime AS mtime, "
@@ -184,7 +187,7 @@ extends WikiDB_backend
         // Note that this will fail silently if the page does not
         // have a record in the page table.  Since it's just the
         // hit count, who cares?
-        $dbh->Execute(sprintf("UPDATE %s SET hits=hits+1 WHERE pagename=%s LIMIT 1",
+        $dbh->Execute(sprintf("UPDATE %s SET hits=hits+1 WHERE pagename=%s",
                               $this->_table_names['page_tbl'],
                               $dbh->qstr($pagename)));
         return;
@@ -217,7 +220,7 @@ extends WikiDB_backend
             // Note that this will fail silently if the page does not
             // have a record in the page table.  Since it's just the
             // hit count, who cares?
-            $dbh->Execute(sprintf("UPDATE $page_tbl SET hits=%d WHERE pagename=%s LIMIT 1",
+            $dbh->Execute(sprintf("UPDATE $page_tbl SET hits=%d WHERE pagename=%s",
                                   $newdata['hits'], $dbh->qstr($pagename)));
             return;
         }
@@ -244,8 +247,8 @@ extends WikiDB_backend
         }
         if ($dbh->Execute("UPDATE $page_tbl"
                           . " SET hits=?, pagedata=?"
-                          . " WHERE pagename=? LIMIT 1",
-                          array($hits, $this->_serialize($data),$pagename))) {
+                          . " WHERE pagename=?",
+                          array($hits, $this->_serialize($data), $pagename))) {
             $dbh->CommitTrans( );
             return true;
         } else {
@@ -268,8 +271,7 @@ extends WikiDB_backend
         if (empty($data)) $data = '';
         $rs = $dbh->Execute("UPDATE $page_tbl"
                             . " SET cached_html=?"
-                            . " WHERE pagename=?"
-                            . " LIMIT 1",
+                            . " WHERE pagename=?",
                             array($data, $pagename));
     }
 
@@ -294,31 +296,21 @@ extends WikiDB_backend
         }
         $row = $dbh->GetRow($query);
         if (! $row ) {
-            //mysql, mysqli or mysqlt
-            if (substr($dbh->databaseType,0,5) == 'mysql') {
-                // have auto-incrementing, atomic version
-                $rs = $dbh->Execute(sprintf("INSERT INTO $page_tbl"
-                                            . " (id,pagename)"
-                                            . " VALUES(NULL,%s)",
-                                            $dbh->qstr($pagename)));
-                $id = $dbh->_insertid();
-            } else {
-                //$id = $dbh->GenID($page_tbl . 'seq');
-                // Better generic version than with adodob::genID
-                //TODO: Does the DBM has subselects? Then we can do it with select max(id)+1
-                $this->lock(array('page'));
-                $dbh->BeginTrans( );
-                $dbh->CommitLock($page_tbl);
-                $row = $dbh->GetRow("SELECT MAX(id) FROM $page_tbl");
-                $id = $row[0] + 1;
-                $rs = $dbh->Execute(sprintf("INSERT INTO $page_tbl"
-                                            . " (id,pagename,hits)"
-                                            . " VALUES (%d,%s,0)",
-                                            $id, $dbh->qstr($pagename)));
-                if ($rs) $dbh->CommitTrans( );
-                else $dbh->RollbackTrans( );
-                $this->unlock(array('page'));
-            }
+	    //$id = $dbh->GenID($page_tbl . 'seq');
+	    // Better generic version than with adodob::genID
+	    //TODO: Does the DBM has subselects? Then we can do it with select max(id)+1
+	    // $this->lock(array('page'));
+	    $dbh->BeginTrans( );
+	    $dbh->CommitLock($page_tbl);
+	    $row = $dbh->GetRow("SELECT MAX(id) FROM $page_tbl");
+	    $id = $row[0] + 1;
+	    $rs = $dbh->Execute(sprintf("INSERT INTO $page_tbl"
+					. " (id,pagename,hits)"
+					. " VALUES (%d,%s,0)",
+					$id, $dbh->qstr($pagename)));
+	    if ($rs) $dbh->CommitTrans( );
+	    else $dbh->RollbackTrans( );
+	    // $this->unlock(array('page'));
         } else {
             $id = $row[0];
         }
@@ -423,7 +415,9 @@ extends WikiDB_backend
         else
             $data['%content'] = '';
         if (!empty($pagedata)) {
-            $data['%pagedata'] = $this->_extract_page_data($pagedata, $hits);
+            // hmm, $pagedata = is already extracted by WikiDB_backend_ADODB_iter
+            //$data['%pagedata'] = $this->_extract_page_data($pagedata, $hits);
+            $data['%pagedata'] = $pagedata;
         }
         return $data;
     }
@@ -451,24 +445,14 @@ extends WikiDB_backend
         $dbh->CommitLock($version_tbl);
         $id = $this->_get_pageid($pagename, true);
         $backend_type = $this->backendType();
-        // optimize: mysql can do this with one REPLACE INTO.
-        if (substr($backend_type,0,5) == 'mysql') {
-            $rs = $dbh->Execute(sprintf("REPLACE INTO $version_tbl"
-                                  . " (id,version,mtime,minor_edit,content,versiondata)"
-                                  . " VALUES(%d,%d,%d,%d,%s,%s)",
-                                  $id, $version, $mtime, $minor_edit,
-                                  $dbh->qstr($content),
-                                  $dbh->qstr($this->_serialize($data))));
-        } else {
-            $dbh->Execute(sprintf("DELETE FROM $version_tbl"
-                                  . " WHERE id=%d AND version=%d",
-                                  $id, $version));
-            $rs = $dbh->Execute("INSERT INTO $version_tbl"
-                                . " (id,version,mtime,minor_edit,content,versiondata)"
-                                . " VALUES(?,?,?,?,?,?)",
-                                  array($id, $version, $mtime, $minor_edit,
+	$dbh->Execute(sprintf("DELETE FROM $version_tbl"
+			      . " WHERE id=%d AND version=%d",
+			      $id, $version));
+	$rs = $dbh->Execute("INSERT INTO $version_tbl"
+			    . " (id,version,mtime,minor_edit,content,versiondata)"
+			    . " VALUES(?,?,?,?,?,?)",
+			    array($id, $version, $mtime, $minor_edit,
                                   $content, $this->_serialize($data)));
-        }
         $this->_update_recent_table($id);
         $this->_update_nonempty_table($id);
         if ($rs) $dbh->CommitTrans( );
@@ -591,7 +575,7 @@ extends WikiDB_backend
         $this->lock(array('link'));
         $pageid = $this->_get_pageid($pagename, true);
 
-        if ($links) {
+        if (1 or $links) {
             $dbh->Execute("DELETE FROM $link_tbl WHERE linkfrom=$pageid");
             foreach ($links as $link) {
                 if (isset($linkseen[$link]))
@@ -602,17 +586,19 @@ extends WikiDB_backend
                 $dbh->Execute("INSERT INTO $link_tbl (linkfrom, linkto)"
                             . " VALUES ($pageid, $linkid)");
             }
-        } elseif (DEBUG) {
+        } elseif (0 and DEBUG) {
             // purge page table: delete all non-referenced pages
             // for all previously linked pages...
             foreach ($dbh->getRow("SELECT $link_tbl.linkto as id FROM $link_tbl".
                                   " WHERE linkfrom=$pageid") as $id) {
             	// ...check if the page is empty and has no version
+                //FIXME: ISNULL is mysql specific
                 if ($dbh->getRow("SELECT $page_tbl.id FROM $page_tbl"
                                  . " LEFT JOIN $nonempty_tbl USING (id) "
                                  . " LEFT JOIN $version_tbl USING (id)"
-                                 . " WHERE ISNULL($nonempty_tbl.id) AND"
-                                 . " ISNULL($version_tbl.id) AND $page_tbl.id=$id")) {
+                                 . " WHERE $nonempty_tbl.id is NULL"
+                                 . " AND $version_tbl.id is NULL"
+                                 . " AND $page_tbl.id=$id")) {
                     $dbh->Execute("DELETE FROM $page_tbl WHERE id=$id");   // this purges the link
                     $dbh->Execute("DELETE FROM $recent_tbl WHERE id=$id"); // may fail
                 }
@@ -648,8 +634,7 @@ extends WikiDB_backend
 
         $qpagename = $dbh->qstr($pagename);
         // removed ref to FETCH_MODE in next line
-        $sql = "SELECT $want.id AS id, $want.pagename AS pagename,"
-            . " $want.hits AS hits"
+        $sql = "SELECT $want.id AS id, $want.pagename AS pagename"
             . " FROM $link_tbl, $page_tbl linker, $page_tbl linkee"
             . (!$include_empty ? ", $nonempty_tbl" : '')
             . " WHERE linkfrom=linker.id AND linkto=linkee.id"
@@ -665,7 +650,7 @@ extends WikiDB_backend
         } else {
             $result = $dbh->Execute($sql);
         }
-        return new WikiDB_backend_ADODB_iter($this, $result, $this->page_tbl_field_list);
+        return new WikiDB_backend_ADODB_iter($this, $result, $this->links_field_list);
     }
 
     /**
@@ -685,8 +670,7 @@ extends WikiDB_backend
                             . " FROM $link_tbl, $page_tbl linker, $page_tbl linkee, $nonempty_tbl"
                             . " WHERE linkfrom=linker.id AND linkto=linkee.id"
                             . " AND $have.pagename=$qpagename"
-                            . " AND $want.pagename=$qlink"
-                            . "LIMIT 1");
+                            . " AND $want.pagename=$qlink");
         return $row[0];
     }
 
@@ -752,9 +736,11 @@ extends WikiDB_backend
     }
         
     /**
-     * Title search.
+     * Title and fulltext search.
      */
-    function text_search($search, $fullsearch=false, $sortby=false, $limit=false, $exclude=false) {
+    function text_search($search, $fullsearch=false, 
+                         $sortby=false, $limit=false, $exclude=false) 
+    {
         $dbh = &$this->_dbh;
         extract($this->_table_names);
         $orderby = $this->sortby($sortby, 'db');
@@ -774,7 +760,8 @@ extends WikiDB_backend
             $join_clause .= " AND $page_tbl.id=$version_tbl.id AND latestversion=version";
 
             $fields .= ",$page_tbl.pagedata as pagedata," . $this->version_tbl_fields;
-            $field_list = array_merge($field_list, array('pagedata'), $this->version_tbl_field_list);
+            $field_list = array_merge($field_list, array('pagedata'), 
+                                      $this->version_tbl_field_list);
             $callback = new WikiMethodCb($searchobj, "_fulltext_match_clause");
         } else {
             $callback = new WikiMethodCb($searchobj, "_pagename_match_clause");
@@ -792,29 +779,11 @@ extends WikiDB_backend
         } else {
             $result = $dbh->Execute($sql);
         }
-        return new WikiDB_backend_ADODB_iter($this, $result, $field_list);
+        $iter = new WikiDB_backend_ADODB_iter($this, $result, $field_list);
+        if ($fullsearch)
+            $iter->stoplisted = $searchobj->stoplisted;
+        return $iter;
     }
-    /*
-    function _sql_match_clause($word) {
-        //not sure if we need this.  ADODB may do it for us
-        $word = preg_replace('/(?=[%_\\\\])/', "\\", $word);  
-
-        // (we need it for at least % and _ --- they're the wildcard characters
-        //  for the LIKE operator, and we need to quote them if we're searching
-        //  for literal '%'s or '_'s.  --- I'm not sure about \, but it seems to
-        //  work as is.
-        $word = $this->_dbh->qstr("%".strtolower($word)."%");
-        $page_tbl = $this->_table_names['page_tbl'];
-        return "LOWER($page_tbl.pagename) LIKE $word";
-    }
-    function _fullsearch_sql_match_clause($word) {
-        $word = preg_replace('/(?=[%_\\\\])/', "\\", $word);  //not sure if we need this
-        // (see above)
-        $word = $this->_dbh->qstr("%".strtolower($word)."%");
-        $page_tbl = $this->_table_names['page_tbl'];
-        return "LOWER($page_tbl.pagename) LIKE $word OR content LIKE $word";
-    }
-    */
 
     /*
      * TODO: efficiently handle wildcards exclusion: exclude=Php* => 'Php%', 
@@ -833,7 +802,7 @@ extends WikiDB_backend
     /**
      * Find highest or lowest hit counts.
      */
-    function most_popular($limit=20, $sortby='-hits') {
+    function most_popular ($limit=20, $sortby='-hits') {
         $dbh = &$this->_dbh;
         extract($this->_table_names);
         $order = "DESC";
@@ -952,23 +921,24 @@ extends WikiDB_backend
             $orderby = 'ORDER BY ' . $orderby;
             
         if ($exclude_from) // array of pagenames
-            $exclude_from = " AND linked.pagename NOT IN ".$this->_sql_set($exclude_from);
+            $exclude_from = " AND pp.pagename NOT IN ".$this->_sql_set($exclude_from);
         if ($exclude) // array of pagenames
-            $exclude = " AND $page_tbl.pagename NOT IN ".$this->_sql_set($exclude);
+            $exclude = " AND p.pagename NOT IN ".$this->_sql_set($exclude);
 
         /* 
          all empty pages, independent of linkstatus:
-           select pagename as empty from page left join nonempty using(id) where isnull(nonempty.id);
+           select pagename as empty from page left join nonempty using(id) where is null(nonempty.id);
          only all empty pages, which have a linkto:
-           select page.pagename, linked.pagename as wantedfrom from link, page as linked 
-             left join page on(link.linkto=page.id) left join nonempty on(link.linkto=nonempty.id) 
-             where isnull(nonempty.id) and linked.id=link.linkfrom;  
+            select page.pagename, linked.pagename as wantedfrom from link, page linked 
+              left join page on link.linkto=page.id left join nonempty on link.linkto=nonempty.id
+              where nonempty.id is null and linked.id=link.linkfrom;  
         */
-        $sql = "SELECT $page_tbl.pagename,linked.pagename as wantedfrom"
-            . " FROM $link_tbl,$page_tbl as linked "
-            . " LEFT JOIN $page_tbl ON($link_tbl.linkto=$page_tbl.id)"
-            . " LEFT JOIN $nonempty_tbl ON($link_tbl.linkto=$nonempty_tbl.id)" 
-            . " WHERE ISNULL($nonempty_tbl.id) AND linked.id=$link_tbl.linkfrom"
+        $sql = "SELECT p.pagename, pp.pagename as wantedfrom"
+            . " FROM $page_tbl p JOIN $link_tbl linked "
+            . " LEFT JOIN $page_tbl pp ON linked.linkto = pp.id"
+            . " LEFT JOIN $nonempty_tbl ne ON linked.linkto = ne.id" 
+            . " WHERE ne.id is NULL"
+            .       " AND p.id = linked.linkfrom"
             . $exclude_from
             . $exclude
             . $orderby;
@@ -1055,10 +1025,10 @@ extends WikiDB_backend
                       . " SELECT $recent_tbl.id"
                       . " FROM $recent_tbl, $version_tbl"
                       . " WHERE $recent_tbl.id=$version_tbl.id"
-                      . "       AND version=latestversion"
+                      .       " AND version=latestversion"
                       // We have some specifics here (Oracle)
                       //. "  AND content<>''"
-                      . "  AND content $notempty"
+                      . "  AND content $notempty" // On Oracle not just "<>''"
                       . ( $pageid ? " AND $recent_tbl.id=$pageid" : ""));
         $this->unlock(array('nonempty'));
     }
@@ -1072,7 +1042,7 @@ extends WikiDB_backend
      * @access protected
      */
     function lock($tables, $write_lock = true) {
-            $this->_dbh->StartTrans();
+	$this->_dbh->StartTrans();
         if ($this->_lock_count++ == 0) {
             $this->_current_lock = $tables;
             $this->_lock_tables($tables, $write_lock);
@@ -1103,7 +1073,7 @@ extends WikiDB_backend
             return;
         }
         if (--$this->_lock_count <= 0 || $force) {
-            $this->_unlock_tables($tables);
+            $this->_unlock_tables($tables, $force);
             $this->_current_lock = false;
             $this->_lock_count = 0;
         }
@@ -1113,7 +1083,7 @@ extends WikiDB_backend
     /**
      * overridden by non-transaction safe backends
      */
-    function _unlock_tables($tables, $write_lock) {
+    function _unlock_tables($tables, $write_lock=false) {
         return;
     }
 
@@ -1264,36 +1234,10 @@ extends WikiDB_backend_ADODB_generic_iter
     }
 }
 
-class WikiDB_backend_ADODB_search
-extends WikiDB_backend_search
+class WikiDB_backend_ADODB_search extends WikiDB_backend_search_sql 
 {
-    function WikiDB_backend_ADODB_search(&$search, &$dbh) {
-        $this->_dbh =& $dbh;
-        $this->_case_exact = $search->_case_exact;
-        $this->_stoplist =& $search->_stoplist;
-    }
-    function _pagename_match_clause($node) {
-        $word = $node->sql();
-        if ($word == '%')
-            return "1=1";
-        else
-            return ($this->_case_exact 
-                    ? "pagename LIKE '$word'"
-                    : "LOWER(pagename) LIKE '$word'");
-    }
-    function _fulltext_match_clause($node) { 
-        $word = $node->sql();
-        if ($word == '%')
-            return "1=1";
-        // eliminate stoplist words
-        if (preg_match("/^%".$this->_stoplist."%/i", $word) 
-            or preg_match("/^".$this->_stoplist."$/i", $word))
-            return $this->_pagename_match_clause($node);
-        else
-            return ($this->_case_exact
-                    ? "pagename LIKE '$word' OR content LIKE '$word'"
-                    : "LOWER(pagename) LIKE '$word' OR content LIKE '$word'");
-    }
+    // no surrounding quotes because we know it's a string
+    // function _quote($word) { return $this->_dbh->escapeSimple($word); }
 }
 
 // Following function taken from Pear::DB (prev. from adodb-pear.inc.php).
@@ -1456,6 +1400,22 @@ extends WikiDB_backend_search
     }
 
 // $Log: ADODB.php,v $
+// Revision 1.88  2006/05/14 12:28:03  rurban
+// mysql 5.x fix for wantedpages join
+//
+// Revision 1.82  2005/10/31 16:48:22  rurban
+// move mysql-specifics into its special class
+//
+// Eliminate stoplist words,
+// don't extract %pagedate twice in ADODB,
+// fix fulltext search,
+//
+// Revision 1.81  2005/10/10 19:42:14  rurban
+// fix wanted_pages SQL syntax
+//
+// Revision 1.79  2005/09/28 19:08:41  rurban
+// dont use LIMIT on modifying queries
+//
 // Revision 1.78  2005/09/14 06:04:43  rurban
 // optimize searching for ALL (ie %), use the stoplist on PDO
 //
