@@ -510,10 +510,12 @@ extends WikiDB_backend
 
 	if ($links) {
             foreach($links as $link) {
+                // avoid duplicates
                 if (isset($linkseen[$link]))
                     continue;
                 $linkseen[$link] = true;
                 $linkid = $this->_get_pageid($link, true);
+                assert($linkid);
                 $dbh->query("INSERT INTO $link_tbl (linkfrom, linkto)"
                             . " VALUES ($pageid, $linkid)");
             }
@@ -541,14 +543,11 @@ extends WikiDB_backend
             $exclude='';
 
         $qpagename = $dbh->escapeSimple($pagename);
-        $sql = "SELECT $want.id as id, $want.pagename as pagename, $want.hits as hits"
-            // Looks like 'AS' in column alias is a MySQL thing, Oracle does not like it
-            // and the PostgresSQL manual does not have it either
-            // Since it is optional in mySQL, just remove it...
+        $sql = "SELECT $want.id AS id, $want.pagename AS pagename "
             . " FROM $link_tbl, $page_tbl linker, $page_tbl linkee"
             . (!$include_empty ? ", $nonempty_tbl" : '')
             . " WHERE linkfrom=linker.id AND linkto=linkee.id"
-            . "  AND $have.pagename='$qpagename'"
+            . " AND $have.pagename='$qpagename'"
             . (!$include_empty ? " AND $nonempty_tbl.id=$want.id" : "")
             //. " GROUP BY $want.id"
             . $exclude
@@ -577,12 +576,13 @@ extends WikiDB_backend
             list($have, $want) = array('linker', 'linkee');
         $qpagename = $dbh->escapeSimple($pagename);
         $qlink = $dbh->escapeSimple($link);
-        $row = $dbh->GetRow("SELECT IF($want.pagename,1,0) as result"
-                                . " FROM $link_tbl, $page_tbl linker, $page_tbl linkee, $nonempty_tbl"
-                                . " WHERE linkfrom=linker.id AND linkto=linkee.id"
-                                . " AND $have.pagename='$qpagename'"
-                                . " AND $want.pagename='$qlink'"
-                                . " LIMIT 1");
+        $row = $dbh->GetRow
+            ("SELECT IF($want.pagename,1,0) as result"
+             . " FROM $link_tbl, $page_tbl linker, $page_tbl linkee, $nonempty_tbl"
+             . " WHERE linkfrom=linker.id AND linkto=linkee.id"
+             . " AND $have.pagename='$qpagename'"
+             . " AND $want.pagename='$qlink'"
+             . " LIMIT 1");
         return $row['result'];
     }
 
@@ -651,6 +651,7 @@ extends WikiDB_backend
         extract($this->_table_names);
         $orderby = $this->sortby($sortby, 'db');
         if ($orderby) $orderby = ' ORDER BY ' . $orderby;
+        //else " ORDER BY rank($field, to_tsquery('$searchon')) DESC";
 
         $searchclass = get_class($this)."_search";
         // no need to define it everywhere and then fallback. memory!
@@ -687,7 +688,9 @@ extends WikiDB_backend
              $result = $dbh->query($sql);
          }
         
-        return new WikiDB_backend_PearDB_iter($this, $result);
+        $iter = new WikiDB_backend_PearDB_iter($this, $result);
+        $iter->stoplisted = @$searchobj->stoplisted;
+        return $iter;
     }
 
     //Todo: check if the better Mysql MATCH operator is supported,
@@ -844,15 +847,15 @@ extends WikiDB_backend
             $orderby = 'ORDER BY ' . $orderby;
 
         if ($exclude_from) // array of pagenames
-            $exclude_from = " AND linked.pagename NOT IN ".$this->_sql_set($exclude_from);
+            $exclude_from = " AND pp.pagename NOT IN ".$this->_sql_set($exclude_from);
         if ($exclude) // array of pagenames
-            $exclude = " AND $page_tbl.pagename NOT IN ".$this->_sql_set($exclude);
-
-        $sql = "SELECT $page_tbl.pagename,linked.pagename as wantedfrom"
-            . " FROM $link_tbl,$page_tbl as linked "
-            . " LEFT JOIN $page_tbl ON($link_tbl.linkto=$page_tbl.id)"
-            . " LEFT JOIN $nonempty_tbl ON($link_tbl.linkto=$nonempty_tbl.id)" 
-            . " WHERE ISNULL($nonempty_tbl.id) AND linked.id=$link_tbl.linkfrom"
+            $exclude = " AND p.pagename NOT IN ".$this->_sql_set($exclude);
+        $sql = "SELECT p.pagename, pp.pagename as wantedfrom"
+            . " FROM $page_tbl p, $link_tbl linked "
+            . " LEFT JOIN $page_tbl pp ON linked.linkto = pp.id"
+            . " LEFT JOIN $nonempty_tbl ne ON linked.linkto = ne.id" 
+            . " WHERE ne.id is NULL"
+	    .       " AND p.id = linked.linkfrom"
             . $exclude_from
             . $exclude
             . $orderby;
@@ -876,7 +879,7 @@ extends WikiDB_backend
     /**
      * Rename page in the database.
      */
-    function rename_page($pagename, $to) {
+    function rename_page ($pagename, $to) {
         $dbh = &$this->_dbh;
         extract($this->_table_names);
         
@@ -1144,7 +1147,9 @@ extends WikiDB_backend
 class WikiDB_backend_PearDB_generic_iter
 extends WikiDB_backend_iterator
 {
-    function WikiDB_backend_PearDB_generic_iter($backend, $query_result, $field_list = NULL) {
+    function WikiDB_backend_PearDB_generic_iter($backend, $query_result, 
+                                                $field_list = NULL) 
+    {
         if (DB::isError($query_result)) {
             // This shouldn't happen, I thought.
             $backend->_pear_error_callback($query_result);
@@ -1210,41 +1215,20 @@ extends WikiDB_backend_PearDB_generic_iter
     }
 }
 
-// word search
-class WikiDB_backend_PearDB_search
-extends WikiDB_backend_search
+class WikiDB_backend_PearDB_search extends WikiDB_backend_search_sql 
 {
-    function WikiDB_backend_PearDB_search(&$search, &$dbh) {
-        $this->_dbh = $dbh;
-        $this->_case_exact = $search->_case_exact;
-        $this->_stoplist =& $search->_stoplist;
-    }
-    function _pagename_match_clause($node) { 
-        $word = $node->sql();
-        if ($word == '%')
-            return "1=1";
-        else
-            return ($this->_case_exact 
-                    ? "pagename LIKE '$word'" 
-                    : "LOWER(pagename) LIKE '$word'");
-    }
-    function _fulltext_match_clause($node) { 
-        $word = $node->sql();
-        if ($word == '%')
-            return "1=1";
-        // eliminate stoplist words
-        if (preg_match("/^%".$this->_stoplist."%/i", $word) 
-            or preg_match("/^".$this->_stoplist."$/i", $word))
-            return $this->_pagename_match_clause($node);
-        else
-            return $this->_pagename_match_clause($node)
-                // probably convert this MATCH AGAINST or SUBSTR/POSITION without wildcards
-                . ($this->_case_exact ? " OR content LIKE '$word'" 
-                                      : " OR LOWER(content) LIKE '$word'");
-    }
+    // no surrounding quotes because we know it's a string
+    // function _quote($word) { return $this->_dbh->addq($word); }
 }
 
 // $Log: PearDB.php,v $
+// Revision 1.94  2005/11/14 22:24:33  rurban
+// fix fulltext search,
+// Eliminate stoplist words,
+//
+// Revision 1.93  2005/10/10 19:42:15  rurban
+// fix wanted_pages SQL syntax
+//
 // Revision 1.92  2005/09/14 06:04:43  rurban
 // optimize searching for ALL (ie %), use the stoplist on PDO
 //
