@@ -1,7 +1,6 @@
-<?php rcs_id('$Id: dba.php,v 1.4 2002/01/24 06:53:35 carstenklapp Exp $');
+<?php rcs_id('$Id: dba.php,v 1.7 2004/11/21 11:59:26 rurban Exp $');
 
 require_once('lib/WikiDB/backend/dbaBase.php');
-
 require_once('lib/DbaDatabase.php');
 
 class WikiDB_backend_dba
@@ -13,8 +12,8 @@ extends WikiDB_backend_dbaBase
         $dba_handler = 'gdbm';
         $timeout = 20;
         extract($dbparams);
-        
-        $dbfile = "$directory/$prefix" . 'pagedb' . '.' . $dba_handler;
+        if ($directory) $directory .= "/";
+        $dbfile = $directory . $prefix . 'pagedb' . '.' . $dba_handler;
 
         // FIXME: error checking.
         $db = new DbaDatabase($dbfile, false, $dba_handler);
@@ -37,4 +36,4 @@ extends WikiDB_backend_dbaBase
 // c-hanging-comment-ender-p: nil
 // indent-tabs-mode: nil
 // End:   
-?>
+?>
\ No newline at end of file
