@@ -1,5 +1,5 @@
 <?php //-*-php-*-
-rcs_id('$Id: WikiUserNew.php,v 1.129 2005/06/10 06:10:35 rurban Exp $');
+rcs_id('$Id: WikiUserNew.php,v 1.137 2006/05/03 06:05:37 rurban Exp $');
 /* Copyright (C) 2004,2005 $ThePhpWikiProgrammingTeam
  *
  * This file is part of PhpWiki.
@@ -669,14 +669,14 @@ extends _WikiUser
         }
         if (! $UserName ) {
             // Try reading userid from old PhpWiki cookie formats:
-            if ($cookie = $request->cookies->get_old('WIKI_ID')) {
+            if ($cookie = $request->cookies->get_old(getCookieName())) {
                 if (is_string($cookie) and (substr($cookie,0,2) != 's:'))
                     $UserName = $cookie;
                 elseif (is_array($cookie) and !empty($cookie['userid']))
                     $UserName = $cookie['userid'];
             }
             if (! $UserName and !headers_sent())
-                $request->deleteCookieVar("WIKI_ID");
+                $request->deleteCookieVar(getCookieName());
             else
                 $this->_userid = $UserName;
         }
@@ -721,7 +721,7 @@ extends _WikiUser
                 // new 1.3.8 policy: no array cookies, only plain userid string as in 
                 // the pre 1.3.x versions.
                 // prefs should be stored besides the session in the homepagehandle or in a db.
-                $request->setCookieVar('WIKI_ID', $this->_userid,
+                $request->setCookieVar(getCookieName(), $this->_userid,
                                        COOKIE_EXPIRATION_DAYS, COOKIE_DOMAIN);
                 //$request->setCookieVar(WIKI_NAME, array('userid' => $prefs->get('userid')),
                 //                       COOKIE_EXPIRATION_DAYS, COOKIE_DOMAIN);
@@ -730,7 +730,7 @@ extends _WikiUser
         $packed = $prefs->store();
         $unpacked = $prefs->unpack($packed);
         if (count($unpacked)) {
-            foreach (array('_method','_select','_update') as $param) {
+            foreach (array('_method','_select','_update','_insert') as $param) {
             	if (!empty($this->_prefs->{$param}))
             	    $prefs->{$param} = $this->_prefs->{$param};
             }
@@ -973,7 +973,9 @@ extends _AnonUser
                 unset($this->_auth_dbi);
         }
         if (empty($this->_auth_dbi)) {
-            if ($dbh->getParam('dbtype') != 'SQL' and $dbh->getParam('dbtype') != 'ADODB')
+            if ($dbh->getParam('dbtype') != 'SQL' 
+                and $dbh->getParam('dbtype') != 'ADODB'
+                and $dbh->getParam('dbtype') != 'PDO')
                 return false;
             if (empty($GLOBALS['DBAuthParams']))
                 return false;
@@ -1004,7 +1006,11 @@ extends _AnonUser
     }
 
     // TODO: use it again for the auth and member tables
-    function prepare ($stmt, $variables, $oldstyle = false) {
+    // sprintfstyle vs prepare style: %s or ?
+    //   multiple vars should be executed via prepare(?,?)+execute, 
+    //   single vars with execute(sprintf(quote(var)))
+    // help with position independency
+    function prepare ($stmt, $variables, $oldstyle = false, $sprintfstyle = true) {
         global $request;
         $dbi = $request->getDbh();
         $this->getAuthDbh();
@@ -1013,6 +1019,7 @@ extends _AnonUser
         // old-style strings don't survive pear/Config/IniConfig treatment, that's why we changed it.
         $new = array();
         if (is_array($variables)) {
+            //$sprintfstyle = false;
             for ($i=0; $i < count($variables); $i++) { 
                 $var = $this->_normalize_stmt_var($variables[$i], $oldstyle);
                 if (!$var)
@@ -1020,7 +1027,10 @@ extends _AnonUser
                                           $variables[$i], $stmt), E_USER_WARNING);
                 $variables[$i] = $var;
                 if (!$var) $new[] = '';
-                else $new[] = '%s';
+                else {
+                    $s = "%" . ($i+1) . "s";	
+                    $new[] = $sprintfstyle ? $s : "?";
+                }
             }
         } else {
             $var = $this->_normalize_stmt_var($variables, $oldstyle);
@@ -1029,7 +1039,7 @@ extends _AnonUser
                                       $variables, $stmt), E_USER_WARNING);
             $variables = $var;
             if (!$var) $new = ''; 
-            else $new = '%s'; 
+            else $new = $sprintfstyle ? '%s' : "?"; 
         }
         $prefix = $dbi->getParam('prefix');
         // probably prefix table names if in same database
@@ -1037,13 +1047,14 @@ extends _AnonUser
             ($dbi->getAuthParam('auth_dsn') and $dbi->getParam('dsn') == $dbi->getAuthParam('auth_dsn')))
         {
             if (!stristr($stmt, $prefix)) {
-                //Do it automatically for the lazy admin? Esp. on sf.net it's nice to have
-                trigger_error("TODO: Need to prefix the DBAuthParam tablename in config/config.ini:\n  $stmt",
-                              E_USER_WARNING);
+            	$oldstmt = $stmt;
                 $stmt = str_replace(array(" user "," pref "," member "),
                                     array(" ".$prefix."user ",
                                           " ".$prefix."pref ",
-                                          " ".$prefix."member "),$stmt);
+                                          " ".$prefix."member "), $stmt);
+                //Do it automatically for the lazy admin? Esp. on sf.net it's nice to have
+                trigger_error("Need to prefix the DBAUTH tablename in config/config.ini:\n  $oldstmt \n=> $stmt",
+                              E_USER_WARNING);
             }
         }
         // Preparate the SELECT statement, for ADODB and PearDB (MDB not).
@@ -1068,13 +1079,18 @@ extends _AnonUser
             	// FIXME: strange why this should be needed...
             	include_once("lib/WikiUser/Db.php");
             	include_once("lib/WikiUser/AdoDb.php");
-                _AdoDbPassUser::_AdoDbPassUser($this->_userid,$this->_prefs);
+                _AdoDbPassUser::_AdoDbPassUser($this->_userid, $this->_prefs);
                 return _AdoDbPassUser::getPreferences();
             } elseif ($this->_prefs->_method == 'SQL') {
             	include_once("lib/WikiUser/Db.php");
             	include_once("lib/WikiUser/PearDb.php");
-                _PearDbPassUser::_PearDbPassUser($this->_userid,$this->_prefs);
+                _PearDbPassUser::_PearDbPassUser($this->_userid, $this->_prefs);
                 return _PearDbPassUser::getPreferences();
+            } elseif ($this->_prefs->_method == 'PDO') {
+            	include_once("lib/WikiUser/Db.php");
+            	include_once("lib/WikiUser/PdoDb.php");
+                _PdoDbPassUser::_PdoDbPassUser($this->_userid, $this->_prefs);
+                return _PdoDbPassUser::getPreferences();
             }
         }
 
@@ -1101,7 +1117,7 @@ extends _AnonUser
             	// FIXME: strange why this should be needed...
             	include_once("lib/WikiUser/Db.php");
             	include_once("lib/WikiUser/AdoDb.php");
-                _AdoDbPassUser::_AdoDbPassUser($this->_userid,$prefs);
+                _AdoDbPassUser::_AdoDbPassUser($this->_userid, $prefs);
                 return _AdoDbPassUser::setPreferences($prefs, $id_only);
             }
             elseif ($this->_prefs->_method == 'SQL') {
@@ -1110,14 +1126,20 @@ extends _AnonUser
                 _PearDbPassUser::_PearDbPassUser($this->_userid, $prefs);
                 return _PearDbPassUser::setPreferences($prefs, $id_only);
             }
+            elseif ($this->_prefs->_method == 'PDO') {
+            	include_once("lib/WikiUser/Db.php");
+            	include_once("lib/WikiUser/PdoDb.php");
+                _PdoDbPassUser::_PdoDbPassUser($this->_userid, $prefs);
+                return _PdoDbPassUser::setPreferences($prefs, $id_only);
+            }
         }
-        if (_AnonUser::setPreferences($prefs, $id_only)) {
+        if ($updated = _AnonUser::setPreferences($prefs, $id_only)) {
             // Encode only the _prefs array of the UserPreference object
-            if ($this->_HomePagehandle and !$id_only) {
+            if (!empty($this->_HomePagehandle) and !$id_only) {
                 $this->_HomePagehandle->set('pref', $this->_prefs->store());
             }
         }
-        return;
+        return $updated;
     }
 
     function mayChangePass() {
@@ -1774,7 +1796,7 @@ class UserPreferences
                     'noLinkIcons'   => new _UserPreference_bool(),    // 1.3.8 
                     'editHeight'    => new _UserPreference_int(EDITHEIGHT_DEFAULT_ROWS,
                                                                EDITHEIGHT_MIN_ROWS,
-                                                               EDITHEIGHT_DEFAULT_ROWS),
+                                                               EDITHEIGHT_MAX_ROWS),
                     'timeOffset'    => new _UserPreference_numeric(TIMEOFFSET_DEFAULT_HOURS,
                                                                    TIMEOFFSET_MIN_HOURS,
                                                                    TIMEOFFSET_MAX_HOURS),
@@ -1786,7 +1808,7 @@ class UserPreferences
         // FIXME: on theme changes the wiki_user session pref object will fail. 
         // We will silently ignore this.
         if (!empty($customUserPreferenceColumns))
-            $this->_prefs = array_merge($this->_prefs,$customUserPreferenceColumns);
+            $this->_prefs = array_merge($this->_prefs, $customUserPreferenceColumns);
 /*
         if (isset($this->_method) and $this->_method == 'SQL') {
             //unset($this->_prefs['userid']);
@@ -1839,7 +1861,11 @@ class UserPreferences
         if ($name == 'theme' and $value == '')
            return true;
         */
-        if (!isset($pref->{$value}) or $pref->{$value} != $pref->default_value) {
+        // Fix Fatal error for undefined value. Thanks to Jim Ford and Joel Schaubert
+        if ((!$value and $pref->default_value)
+            or ($value and !isset($pref->{$name})) // bug #1355533
+            or ($value and ($pref->{$name} != $pref->default_value)))
+        {
             if ($name == 'emailVerified') $newvalue = $value;
             else $newvalue = $pref->sanify($value);
 	    $pref->set($name, $newvalue);
@@ -1857,7 +1883,7 @@ class UserPreferences
             $type = 'emailVerified'; $obj =& $this->_prefs['email'];
             $obj->_init = $init;
             if ($obj->get($type) !== $prefs->get($type)) {
-                if ($obj->set($type,$prefs->get($type)))
+                if ($obj->set($type, $prefs->get($type)))
                     $count++;
             }
             foreach (array_keys($this->_prefs) as $type) {
@@ -1869,7 +1895,7 @@ class UserPreferences
                         $obj->get($type) == THEME) continue;
                     if ($type == 'lang' and $prefs->get($type) == '' and 
                         $obj->get($type) == DEFAULT_LANGUAGE) continue;
-                    if ($this->_prefs[$type]->set($type,$prefs->get($type)))
+                    if ($this->_prefs[$type]->set($type, $prefs->get($type)))
                         $count++;
                 }
             }
@@ -1919,7 +1945,10 @@ class UserPreferences
             if ($name == 'email' and ($value = $object->getraw('emailVerified')))
                 $prefs['emailVerified'] = $value;
             if ($name == 'passwd' and $value and ENCRYPTED_PASSWD) {
-            	$prefs['passwd'] = crypt($value);
+                if (strlen($value) != strlen(crypt('test')))
+                    $prefs['passwd'] = crypt($value);
+                else // already crypted
+                    $prefs['passwd'] = $value;
             }
         }
         return $this->pack($prefs);
@@ -2005,7 +2034,7 @@ class UserPreferences
     }
 
     function hash () {
-        return hash($this->_prefs);
+        return wikihash($this->_prefs);
     }
 }
 
@@ -2078,6 +2107,28 @@ extends UserPreferences
 */
 
 // $Log: WikiUserNew.php,v $
+// Revision 1.137  2006/05/03 06:05:37  rurban
+// Fix default preferences for editheight maxrows, by Manuel Vacelet.
+//
+// Revision 1.136  2006/04/16 11:07:48  rurban
+// Dont crypt the passwd twice on storing prefs. Patch by Thomas Harding.
+// Fixes bug #1327470
+//
+// Revision 1.135  2006/03/19 16:26:39  rurban
+// fix DBAUTH arguments to be position independent, fixes bug #1358973
+//
+// Revision 1.134  2006/03/19 15:01:00  rurban
+// sf.net patch #1333957 by Matt Brown: Authentication cookie identical across all wikis on a host
+//
+// Revision 1.133  2006/03/07 18:39:21  rurban
+// add PdoDb, rename hash to wikihash (php-5.1), fix output of Homepage prefs update
+//
+// Revision 1.132  2006/03/04 13:19:12  rurban
+// fix for fatal error on empty pref value (sign out). Thanks to Jim Ford and Joel Schaubert. rename hash for php-5.1
+//
+// Revision 1.131  2005/10/12 06:16:48  rurban
+// add new _insert statement
+//
 // Revision 1.129  2005/06/10 06:10:35  rurban
 // ensure Update Preferences gets through
 //
