@@ -29,12 +29,15 @@ class PageEditor
                 $request->redirect(WikiURL($this->page->getName())); // noreturn
         }
         
-        
         $this->meta = array('author' => $this->user->getId(),
                             'author_id' => $this->user->getAuthenticatedId(),
                             'mtime' => time());
         
         $this->tokens = array();
+        if (ENABLE_CAPTCHA) {
+            require_once('lib/Captcha.php');
+            $this->Captcha = new Captcha($this->meta);
+        }
         
         $version = $request->getArg('version');
         if ($version !== false) {
@@ -55,7 +58,8 @@ class PageEditor
 
             // The edit request has specified some initial content from a template 
             if (  ($template = $request->getArg('template'))
-                   and $request->_dbi->isWikiPage($template)) {
+                   and $request->_dbi->isWikiPage($template)) 
+            {
                 $page = $request->_dbi->getPage($template);
                 $current = $page->getCurrentRevision();
                 $this->_content = $current->getPackedContent();
@@ -74,14 +78,15 @@ class PageEditor
         $tokens = &$this->tokens;
         $tokens['PAGE_LOCKED_MESSAGE'] = '';
         $tokens['CONCURRENT_UPDATE_MESSAGE'] = '';
+        $r =& $this->request;
 
-        if (isset($this->request->args['pref']['editWidth'])
-            and ($this->request->getPref('editWidth') != $this->request->args['pref']['editWidth'])) {
-            $this->request->_prefs->set('editWidth', $this->request->args['pref']['editWidth']);
+        if (isset($r->args['pref']['editWidth'])
+            and ($r->getPref('editWidth') != $r->args['pref']['editWidth'])) {
+            $r->_prefs->set('editWidth', $r->args['pref']['editWidth']);
         }
-        if (isset($this->request->args['pref']['editHeight'])
-            and ($this->request->getPref('editHeight') != $this->request->args['pref']['editHeight'])) {
-            $this->request->_prefs->set('editHeight', $this->request->args['pref']['editHeight']);
+        if (isset($r->args['pref']['editHeight'])
+            and ($r->getPref('editHeight') != $r->args['pref']['editHeight'])) {
+            $r->_prefs->set('editHeight', $r->args['pref']['editHeight']);
         }
 
         if (! $this->canEdit()) {
@@ -89,28 +94,29 @@ class PageEditor
                 return $this->viewSource();
             $tokens['PAGE_LOCKED_MESSAGE'] = $this->getLockedMessage();
         }
-        elseif ($this->request->getArg('save_and_redirect_to') != "") {
-            if (ENABLE_CAPTCHA && $this->captchaFailed()) {
+        elseif ($r->getArg('save_and_redirect_to') != "") {
+            if (ENABLE_CAPTCHA && $this->Captcha->Failed()) {
 		$this->tokens['PAGE_LOCKED_MESSAGE'] = 
-                    HTML::p(HTML::h1(_("Typed in verification word mismatch ... are you a bot?")));
+                    HTML::p(HTML::h1($this->Captcha->failed_msg));
 	    }
             elseif ( $this->savePage()) {
                 // noreturn
-                $this->request->redirect(WikiURL($this->request->getArg('save_and_redirect_to')));
+                $r->redirect(WikiURL($r->getArg('save_and_redirect_to')));
                 return true;    // Page saved.
             }
             $saveFailed = true;
         }
         elseif ($this->editaction == 'save') {
-            if (ENABLE_CAPTCHA && $this->captchaFailed()) {
+            if (ENABLE_CAPTCHA && $this->Captcha->Failed()) {
 		$this->tokens['PAGE_LOCKED_MESSAGE'] = 
-                    HTML::p(HTML::h1(_("Typed in verification word mismatch ... are you a bot?")));
+                    HTML::p(HTML::h1($this->Captcha->failed_msg));
 	    }
             elseif ($this->savePage()) {
                 return true;    // Page saved.
             }
-            else
+            else {
                 $saveFailed = true;
+            }
         }
 
         if ($saveFailed and $this->isConcurrentUpdate())
@@ -132,8 +138,9 @@ class PageEditor
             $this->_currentVersion = $this->current->getVersion();
             $this->version = $this->_currentVersion;
             $unresolved = $diff->ConflictingBlocks;
-            $tokens['CONCURRENT_UPDATE_MESSAGE'] = $this->getConflictMessage($unresolved);
-        } elseif ($saveFailed) {
+            $tokens['CONCURRENT_UPDATE_MESSAGE'] 
+                = $this->getConflictMessage($unresolved);
+        } elseif ($saveFailed && !$this->_isSpam) {
             $tokens['CONCURRENT_UPDATE_MESSAGE'] = 
                 HTML(HTML::h2(_("Some internal editing error")),
             	     HTML::p(_("Your are probably trying to edit/create an invalid version of this page.")),
@@ -171,7 +178,6 @@ class PageEditor
             $pagelink = WikiLink($this->page);
         }
 
-
         $title = new FormattedText ($title_fs, $pagelink);
         if (USE_HTMLAREA and $template == 'editpage') {
             $WikiTheme->addMoreHeaders(Edit_HtmlArea_Head());
@@ -188,6 +194,7 @@ class PageEditor
         assert($this->selected);
 
         $this->tokens['PAGE_SOURCE'] = $this->_content;
+        $this->tokens['HIDDEN_INPUTS'] = HiddenInputs($this->request->getArgs());
         return $this->output('viewsource', _("View Source: %s"));
     }
 
@@ -227,7 +234,8 @@ class PageEditor
             return true;
         }
 
-        if ($this->isSpam()) {
+        if (!$this->user->isAdmin() and $this->isSpam()) {
+            $this->_isSpam = true;
             return false;
             /*
             // Save failed. No changes made.
@@ -272,11 +280,11 @@ class PageEditor
         $cleaner = new ArchiveCleaner($GLOBALS['ExpireParams']);
         $cleaner->cleanPageRevisions($page);
 
-        /* generate notification emails done in WikiDB::save to catch all direct calls 
-          (admin plugins) */
+        /* generate notification emails done in WikiDB::save to catch 
+         all direct calls (admin plugins) */
 
         // look at the errorstack
-        $errors = $GLOBALS['ErrorManager']->_postponed_errors;
+        $errors   = $GLOBALS['ErrorManager']->_postponed_errors;
         $warnings = $GLOBALS['ErrorManager']->getPostponedErrorsAsHTML(); 
         $GLOBALS['ErrorManager']->_postponed_errors = $errors;
 
@@ -307,19 +315,6 @@ class PageEditor
         return true;
     }
 
-    function captchaFailed () {
-	if ($this->request->getSessionVar('captcha_ok') == true)
-	    return false;
-	
-	if ( ! array_key_exists ( 'captcha_input', $this->meta )
-             or ($this->request->getSessionVar('captchaword')
-                 and ($this->request->getSessionVar('captchaword') != $this->meta['captcha_input'])))
-	    return true;
-	
-	$this->request->setSessionVar('captcha_ok', true);
-	return false;
-    }
-
     function isConcurrentUpdate () {
         assert($this->current->getVersion() >= $this->_currentVersion);
         return $this->current->getVersion() != $this->_currentVersion;
@@ -347,12 +342,9 @@ class PageEditor
      * Need to check dynamically some blacklist wikipage settings 
      * (plugin WikiAccessRestrictions) and some static blacklist.
      * DONE: 
-     *   More then 20 new external links
-     *   content patterns by babycart (only php >= 4.3 for now)
-     * TODO:
-     *   IP blacklist 
-     *   domain blacklist
-     *   url patterns
+     *   Always: More then 20 new external links
+     *   ENABLE_SPAMASSASSIN:  content patterns by babycart (only php >= 4.3 for now)
+     *   ENABLE_SPAMBLOCKLIST: content domain blacklist
      */
     function isSpam () {
         $current = &$this->current;
@@ -360,37 +352,63 @@ class PageEditor
 
         $oldtext = $current->getPackedContent();
         $newtext =& $this->_content;
+
+        // FIXME: in longer texts the NUM_SPAM_LINKS number should be increased.
+        //        better use a certain text : link ratio.
+
         // 1. Not more then 20 new external links
-        if ($this->numLinks($newtext) - $this->numLinks($oldtext) >= 20) {
-            // mail the admin?
+        if ($this->numLinks($newtext) - $this->numLinks($oldtext) >= NUM_SPAM_LINKS)
+        {
+            // Allow strictly authenticated users?
+            // TODO: mail the admin?
             $this->tokens['PAGE_LOCKED_MESSAGE'] = 
                 HTML($this->getSpamMessage(),
-                     HTML::p(HTML::em(_("Too many external links."))));
+                     HTML::p(HTML::strong(_("Too many external links."))));
             return true;
         }
         // 2. external babycart (SpamAssassin) check
         // This will probably prevent from discussing sex or viagra related topics. So beware.
         if (ENABLE_SPAMASSASSIN) {
-            $user = $request->getUser();
             include_once("lib/spam_babycart.php");
             if ($babycart = check_babycart($newtext, $request->get("REMOTE_ADDR"), 
-                                           $user->getId())) {
-                // mail the admin?
+                                           $this->user->getId())) {
+                // TODO: mail the admin
                 if (is_array($babycart))
                     $this->tokens['PAGE_LOCKED_MESSAGE'] = 
                         HTML($this->getSpamMessage(),
-                             HTML::p(HTML::em(_("SpamAssassin reports: ", 
-                                                join("\n", $babycart)))));
+                             HTML::p(HTML::em(_("SpamAssassin reports: "), 
+                                                join("\n", $babycart))));
                 return true;
             }
         }
+        // 3. extract (new) links and check surbl for blocked domains
+        if (ENABLE_SPAMBLOCKLIST and $this->numLinks($newtext)) {
+            include_once("lib/SpamBlocklist.php");
+            include_once("lib/InlineParser.php");
+            $parsed = TransformLinks($newtext);
+            foreach ($parsed->_content as $link) {
+            	if (isa($link, 'Cached_ExternalLink')) {
+                  $uri = $link->_getURL($this->page->getName());
+                  if ($res = IsBlackListed($uri)) {
+                    // TODO: mail the admin
+                    $this->tokens['PAGE_LOCKED_MESSAGE'] = 
+                        HTML($this->getSpamMessage(),
+                             HTML::p(HTML::strong(_("External links contain blocked domains:")),
+                             HTML::ul(HTML::li(sprintf(_("%s is listed at %s"), 
+                                                       $res[2], $res[0])))));
+                    return true;
+                  }
+            	}
+            }
+        }
+
         return false;
     }
 
     /** Number of external links in the wikitext
      */
     function numLinks(&$text) {
-        return substr_count($text, "http://");
+        return substr_count($text, "http://") + substr_count($text, "https://");
     }
 
     /** Header of the Anti Spam message 
@@ -472,8 +490,6 @@ class PageEditor
     function getTextArea () {
         $request = &$this->request;
 
-        // wrap=virtual is not HTML4, but without it NS4 doesn't wrap
-        // long lines
         $readonly = ! $this->canEdit(); // || $this->isConcurrentUpdate();
         if (USE_HTMLAREA) {
             $html = $this->getPreview();
@@ -481,16 +497,16 @@ class PageEditor
             $this->_content = $html->asXML();
         }
 
-        /** <textarea wrap="virtual"> is not valid xhtml but Netscape 4 requires it
-         * to wrap long lines.
-         */
-        $textarea = HTML::textarea(array('class' => 'wikiedit',
+        $textarea = HTML::textarea(array('class'=> 'wikiedit',
                                          'name' => 'edit[content]',
                                          'id'   => 'edit[content]',
                                          'rows' => $request->getPref('editHeight'),
                                          'cols' => $request->getPref('editWidth'),
                                          'readonly' => (bool) $readonly),
                                    $this->_content);
+        /** <textarea wrap="virtual"> is not valid XHTML but Netscape 4 requires it
+         * to wrap long lines.
+         */
         if (isBrowserNS4())
             $textarea->setAttr('wrap', 'virtual');
         if (USE_HTMLAREA)
@@ -512,20 +528,9 @@ class PageEditor
 
         $el['HIDDEN_INPUTS'] = HiddenInputs($h);
         $el['EDIT_TEXTAREA'] = $this->getTextArea();
-        if ( ENABLE_CAPTCHA && ! $request->getSessionVar('captchaword')) {
-	    $request->setSessionVar('captchaword', get_captcha_word());
-	}
-	if ( ENABLE_CAPTCHA && ! $request->getSessionVar('captcha_ok')) {
-	    $el['CAPTCHA_INPUT']
-		= HTML::input(array('type'  => 'text',
-				    'class' => 'wikitext',
-				    'id'    => 'edit[captcha_input]',
-				    'name'  => 'edit[captcha_input]',
-				    'size'  => 20,
-				    'maxlength' => 256));
-	    $el['CAPTCHA_IMAGE'] = '<img src="?action=captcha" alt="captcha" />';
-	    $el['CAPTCHA_LABEL'] = '<label for="edit[captcha_input]">'._("Type word above:").' </label>';
-	}
+        if ( ENABLE_CAPTCHA ) {
+            $el = array_merge($el, $this->Captcha->getFormElements());
+        }
         $el['SUMMARY_INPUT']
             = HTML::input(array('type'  => 'text',
                                 'class' => 'wikitext',
@@ -740,13 +745,14 @@ extends PageEditor
             $pagelink = WikiLink($this->page);
         }
 
-        $title = new FormattedText ($title_fs, $pagelink);
+        //$title = new FormattedText ($title_fs, $pagelink);
         $template = Template($template, $this->tokens);
 
         //GeneratePage($template, $title, $rev);
         PrintXML($template);
         return true;
     }
+
     function getConflictMessage () {
         $message = HTML(HTML::p(fmt("Some of the changes could not automatically be combined.  Please look for sections beginning with '%s', and ending with '%s'.  You will need to edit those sections by hand before you click Save.",
                                     "<<<<<<<",
@@ -758,6 +764,24 @@ extends PageEditor
 
 /**
  $Log: editpage.php,v $
+ Revision 1.106  2005/11/21 22:03:08  rurban
+ fix syntax error inside ENABLE_SPAMBLOCKLIST
+
+ Revision 1.105  2005/11/21 20:53:59  rurban
+ beautify request pref lines, no antispam if admin (netznetz request), user is a member anyway
+
+ Revision 1.101  2005/10/30 16:12:28  rurban
+ simplify viewsource tokens
+
+ Revision 1.100  2005/10/30 14:20:42  rurban
+ move Captcha specific vars and methods into a Captcha object
+ randomize Captcha chars positions and angles (smoothly)
+
+ Revision 1.99  2005/10/29 08:21:58  rurban
+ ENABLE_SPAMBLOCKLIST:
+   Check for links to blocked external tld domains in new edits, against
+   multi.surbl.org and bl.spamcop.net.
+
  Revision 1.96  2005/05/06 17:54:22  rurban
  silence Preview warnings for PAGE_LOCKED_MESSAGE, CONCURRENT_UPDATE_MESSAGE (thanks to schorni)
 
