@@ -155,7 +155,7 @@ function MailifyPage ($page, $nversions = 1)
     $iter = $page->getAllRevisions();
     $parts = array();
     while ($revision = $iter->next()) {
-        $parts[] = MimeifyPageRevision($revision);
+        $parts[] = MimeifyPageRevision($page, $revision);
         if ($nversions > 0 && count($parts) >= $nversions)
             break;
     }
@@ -218,17 +218,17 @@ function MakeWikiZip (&$request)
     } else {
         $excludeList = array();
     }
-    if ($whichpages = $request->getArg('pages')) {  // which pagenames
-        if ($whichpages == '[]') // current page
-            $whichpages = $thispage;
-        $pages = new WikiDB_Array_PageIterator(explodePageList($whichpages));
+    if ($pages = $request->getArg('pages')) {  // which pagenames
+        if ($pages == '[]') // current page
+            $pages = $thispage;
+        $page_iter = new WikiDB_Array_PageIterator(explodePageList($pages));
     } else {
-        $pages = $dbi->getAllPages(false,false,false,$excludeList);
+        $page_iter = $dbi->getAllPages(false,false,false,$excludeList);
     }
     $request_args = $request->args;
     $timeout = (! $request->getArg('start_debug')) ? 30 : 240;
     
-    while ($page = $pages->next()) {
+    while ($page = $page_iter->next()) {
 	$request->args = $request_args; // some plugins might change them (esp. on POST)
         longer_timeout($timeout); 	// Reset watchdog
 
@@ -292,18 +292,18 @@ function DumpToDir (&$request)
     } else {
         $excludeList = array();
     }
-    if ($whichpages = $request->getArg('pages')) {  // which pagenames
-        if ($whichpages == '[]') // current page
-            $whichpages = $thispage;
-        $pages = new WikiDB_Array_PageIterator(explodePageList($whichpages));
+    if ($pages = $request->getArg('pages')) {  // which pagenames
+        if ($pages == '[]') // current page
+            $pages = $thispage;
+        $page_iter = new WikiDB_Array_PageIterator(explodePageList($pages));
     } else {
-        $pages = $dbi->getAllPages(false,false,false,$excludeList);
+        $page_iter = $dbi->getAllPages(false,false,false,$excludeList);
     }
 
     $request_args = $request->args;
     $timeout = (! $request->getArg('start_debug')) ? 30 : 240;
 
-    while ($page = $pages->next()) {
+    while ($page = $page_iter->next()) {
 	$request->args = $request_args; // some plugins might change them (esp. on POST)
         longer_timeout($timeout); 	// Reset watchdog
 
@@ -400,19 +400,22 @@ function DumpHtmlToDir (&$request)
     } else {
         $excludeList = array();
     }
-    if ($whichpages = $request->getArg('pages')) {  // which pagenames
-        if ($whichpages == '[]') // current page
-            $whichpages = $thispage;
-        $pages = new WikiDB_Array_PageIterator(explodePageList($whichpages));
+    if ($pages = $request->getArg('pages')) {  // which pagenames
+        if ($pages == '[]') // current page
+            $pages = $thispage;
+        $page_iter = new WikiDB_Array_PageIterator(explodePageList($pages));
+    // not at admin page: dump only the current page
+    } elseif ($thispage != _("PhpWikiAdministration")) { 
+        $page_iter = new WikiDB_Array_PageIterator(array($thispage));
     } else {
-        $pages = $dbi->getAllPages(false,false,false,$excludeList);
+        $page_iter = $dbi->getAllPages(false,false,false,$excludeList);
     }
 
     global $WikiTheme;
     if (defined('HTML_DUMP_SUFFIX'))
         $WikiTheme->HTML_DUMP_SUFFIX = HTML_DUMP_SUFFIX;
     $WikiTheme->DUMP_MODE = 'HTML';
-    $_bodyAttr = $WikiTheme->_MoreAttr['body'];
+    $_bodyAttr = @$WikiTheme->_MoreAttr['body'];
     unset($WikiTheme->_MoreAttr['body']);
 
     // check if the dumped file will be accessible from outside
@@ -434,7 +437,7 @@ function DumpHtmlToDir (&$request)
     $request_args = $request->args;
     $timeout = (! $request->getArg('start_debug')) ? 20 : 240;
     
-    while ($page = $pages->next()) {
+    while ($page = $page_iter->next()) {
 	$request->args = $request_args; // some plugins might change them (esp. on POST)
         longer_timeout($timeout); 	// Reset watchdog
           
@@ -497,12 +500,15 @@ function DumpHtmlToDir (&$request)
         unset($template);
         unset($data);
     }
-    $pages->free();
+    $page_iter->free();
 
     if (!empty($WikiTheme->dumped_images) and is_array($WikiTheme->dumped_images)) {
         @mkdir("$directory/images");
         foreach ($WikiTheme->dumped_images as $img_file) {
-            if ($img_file and ($from = $WikiTheme->_findFile($img_file, true)) and basename($from)) {
+            if ($img_file 
+                and ($from = $WikiTheme->_findFile($img_file, true)) 
+                and basename($from)) 
+            {
                 $target = "$directory/images/".basename($img_file);
                 if (copy($WikiTheme->_path . $from, $target)) {
                     _copyMsg($from, fmt("... copied to %s", $target));
@@ -518,7 +524,10 @@ function DumpHtmlToDir (&$request)
     	// Buttons also
         @mkdir("$directory/images/buttons");
         foreach ($WikiTheme->dumped_buttons as $text => $img_file) {
-            if ($img_file and ($from = $WikiTheme->_findFile($img_file, true)) and basename($from)) {
+            if ($img_file 
+                and ($from = $WikiTheme->_findFile($img_file, true)) 
+                and basename($from)) 
+            {
                 $target = "$directory/images/buttons/".basename($img_file);
                 if (copy($WikiTheme->_path . $from, $target)) {
                     _copyMsg($from, fmt("... copied to %s", $target));
@@ -532,7 +541,10 @@ function DumpHtmlToDir (&$request)
     }
     if (!empty($WikiTheme->dumped_css) and is_array($WikiTheme->dumped_css)) {
         foreach ($WikiTheme->dumped_css as $css_file) {
-            if ($css_file and ($from = $WikiTheme->_findFile(basename($css_file), true)) and basename($from)) {
+            if ($css_file 
+                and ($from = $WikiTheme->_findFile(basename($css_file), true)) 
+                and basename($from)) 
+            {
                 $target = "$directory/" . basename($css_file);
                 if (copy($WikiTheme->_path . $from, $target)) {
                     _copyMsg($from, fmt("... copied to %s", $target));
@@ -574,19 +586,19 @@ function MakeWikiZipHtml (&$request)
     } else {
         $excludeList = array();
     }
-    if ($whichpages = $request->getArg('pages')) {  // which pagenames
-        if ($whichpages == '[]') // current page
-            $whichpages = $thispage;
-        $pages = new WikiDB_Array_PageIterator(explodePageList($whichpages));
+    if ($pages = $request->getArg('pages')) {  // which pagenames
+        if ($pages == '[]') // current page
+            $pages = $thispage;
+        $page_iter = new WikiDB_Array_PageIterator(explodePageList($pages));
     } else {
-        $pages = $dbi->getAllPages(false,false,false,$excludeList);
+        $page_iter = $dbi->getAllPages(false,false,false,$excludeList);
     }
 
     global $WikiTheme;
     if (defined('HTML_DUMP_SUFFIX'))
         $WikiTheme->HTML_DUMP_SUFFIX = HTML_DUMP_SUFFIX;
     $WikiTheme->DUMP_MODE = 'ZIPHTML';
-    $_bodyAttr = $WikiTheme->_MoreAttr['body'];
+    $_bodyAttr = @$WikiTheme->_MoreAttr['body'];
     unset($WikiTheme->_MoreAttr['body']);
 
     /* ignore fatals in plugins */
@@ -598,7 +610,7 @@ function MakeWikiZipHtml (&$request)
     $request_args = $request->args;
     $timeout = (! $request->getArg('start_debug')) ? 20 : 240;
     
-    while ($page = $pages->next()) {
+    while ($page = $page_iter->next()) {
 	$request->args = $request_args; // some plugins might change them (esp. on POST)
         longer_timeout($timeout); 	// Reset watchdog
 
@@ -643,7 +655,7 @@ function MakeWikiZipHtml (&$request)
         unset($template);
         unset($data);
     }
-    $pages->free();
+    $page_iter->free();
 
     $attrib = false;
     // Deal with css and images here.
@@ -1307,6 +1319,12 @@ function LoadPostFile (&$request)
 
 /**
  $Log: loadsave.php,v $
+ Revision 1.139  2005/08/27 18:02:43  rurban
+ fix and expand pages
+
+ Revision 1.138  2005/08/27 09:39:10  rurban
+ dumphtml when not at admin page: dump the current or given page
+
  Revision 1.137  2005/01/30 23:14:38  rurban
  simplify page names
 
