@@ -662,7 +662,7 @@ class WikiRequest extends Request {
         if ($current->getVersion() > 0)
             return;             // Homepage exists.
 
-        include('lib/loadsave.php');
+        include_once('lib/loadsave.php');
         SetupWiki($this);
         $this->finish();        // NORETURN
     }
@@ -1134,7 +1134,8 @@ class WikiRequest extends Request {
 
     function action_captcha () {
         include_once "lib/Captcha.php";
-        captcha_image ( $this->getSessionVar('captchaword')); 
+        $captcha = new Captcha();
+        $captcha->image ( $captcha->captchaword() ); 
     }
     
 }
@@ -1237,8 +1238,8 @@ if (defined('WIKI_XMLRPC') and WIKI_XMLRPC) return;
 if (defined('WIKI_SOAP')   and WIKI_SOAP)   return;
 
     $validators = array('wikiname' => WIKI_NAME,
-                        'args'     => hash($request->getArgs()),
-                        'prefs'    => hash($request->getPrefs()));
+                        'args'     => wikihash($request->getArgs()),
+                        'prefs'    => wikihash($request->getPrefs()));
     if (CACHE_CONTROL == 'STRICT') {
         $dbi = $request->getDbh();
         $timestamp = $dbi->getTimestamp();
@@ -1272,6 +1273,13 @@ if (!defined('PHPWIKI_NOMAIN') or !PHPWIKI_NOMAIN)
 
 
 // $Log: main.php,v $
+// Revision 1.219  2005/10/30 14:20:42  rurban
+// move Captcha specific vars and methods into a Captcha object
+// randomize Captcha chars positions and angles (smoothly)
+//
+// Revision 1.217  2005/09/18 12:44:00  rurban
+// novatrope patch to let only _AUTHENTICATED view pages
+//
 // Revision 1.216  2005/08/27 09:40:46  rurban
 // fix login with HttpAuth
 //
