@@ -1,7 +1,7 @@
 <?php // -*-php-*-
 rcs_id('$Id: SiteMap.php,v 1.13 2004/12/14 21:36:06 rurban Exp $');
 /**
- Copyright 1999, 2000, 2001, 2002 $ThePhpWikiProgrammingTeam
+ Copyright 1999,2000,2001,2002,2004 $ThePhpWikiProgrammingTeam
 
  This file is part of PhpWiki.
 
@@ -96,7 +96,8 @@ extends WikiPlugin
         while ($link = $pagelinks->next()) {
             $linkpagename = $link->getName();
             if (($linkpagename != $startpagename)
-                && !preg_match("/$this->ExcludedPages/", $linkpagename)) {
+                and (!$this->ExcludedPages or !preg_match("/".$this->ExcludedPages."/", $linkpagename)))
+            {
                 $pagearr[$level . " [$linkpagename]"] = $link;
                 $pagearr = $this->recursivelyGetBackLinks($link, $pagearr,
                                                           $level . '*',
@@ -123,10 +124,10 @@ extends WikiPlugin
         $pagelinks = $startpage->getLinks($reversed);
         while ($link = $pagelinks->next()) {
             $linkpagename = $link->getName();
-            if (($linkpagename != $startpagename)
-                && !preg_match("/$this->ExcludedPages/", $linkpagename)) {
-                if (!$this->excludeunknown
-                    || $this->dbi->isWikiPage($linkpagename)) {
+            if (($linkpagename != $startpagename) and 
+                (!$this->ExcludedPages or !preg_match("/$this->ExcludedPages/", $linkpagename)))
+            {
+                if (!$this->excludeunknown or $this->dbi->isWikiPage($linkpagename)) {
                     $pagearr[$level . " [$linkpagename]"] = $link;
                     $pagearr = $this->recursivelyGetLinks($link, $pagearr,
                                                           $level . '*',
@@ -151,7 +152,7 @@ extends WikiPlugin
         if (empty($exclude)) $exclude = array();
         if (!$include_self)
             $exclude[] = $page;
-        $this->ExcludedPages = "^(?:" . join("|", $exclude) . ")";
+        $this->ExcludedPages = empty($exclude) ? "" : ("^(?:" . join("|", $exclude) . ")");
         $this->_default_limit = str_pad('', 3, '*');
         if (is_numeric($reclimit)) {
             if ($reclimit < 0)
@@ -202,7 +203,8 @@ extends WikiPlugin
                 $a = substr_count($key, '*');
                 $indenter = str_pad($nothing, $a);
                 //$request->setArg('IncludePage', 1);
-                $plugin_args = 'page=' . $link->getName() . ' ' . $includepages;
+                // quote linkname, by Stefan Schorn
+                $plugin_args = 'page=\'' . $link->getName() . '\' ' . $includepages;
                 $pagehtml = $plugin->run($dbi, $plugin_args, $request, $basepage);
                 $html->pushContent($pagehtml); 
                 //$html->pushContent( HTML(TransformText($indenter, 1.0, $page), $pagehtml)); 
@@ -272,4 +274,4 @@ extends WikiPlugin
 // c-hanging-comment-ender-p: nil
 // indent-tabs-mode: nil
 // End:
-?>
+?>
\ No newline at end of file
