@@ -54,8 +54,10 @@
 
     file_mtime ($filename)
     sort_file_mtime ($a, $b)
-    class fileSet {fileSet($directory, $filepattern = false), getFiles($exclude=false, $sortby=false, $limit=false) }
-    class ListRegexExpand { listMatchCallback($item, $key),  expandRegex ($index, &$pages) }
+    class fileSet {fileSet($directory, $filepattern = false), 
+                   getFiles($exclude=false, $sortby=false, $limit=false) }
+    class ListRegexExpand { listMatchCallback($item, $key),  
+                            expandRegex ($index, &$pages) }
 
     glob_to_pcre ($glob)
     glob_match ($glob, $against, $case_sensitive = true)
@@ -64,7 +66,7 @@
     isa ($object, $class)
     can ($object, $method)
     function_usable ($function_name)
-    hash ($x)
+    wikihash ($x)
     better_srand ($seed = '')
     count_all ($arg)
     isSubPage ($pagename)
@@ -462,7 +464,7 @@ function LinkImage($url, $alt = false) {
  * $alt may be an alternate img
  * TODO: Need to unify with WikiPluginCached::embedObject()
  *
- * Note that Safari 1.0 will crash with <object>, use only <embed>
+ * Note that Safari 1.0 will crash with <object>, so use only <embed>
  *   http://www.alleged.org.uk/pdc/2002/svg-object.html
  */
 function ImgObject($img, $url) {
@@ -1535,7 +1537,8 @@ function explodePageList($input, $include_empty=false, $sortby='pagename',
 /** 
  * Determine whether object is of a specified type.
  * In PHP builtin since 4.2.0 as is_a()
- *
+ * is_a() deprecated in PHP 5, in favor of instanceof operator
+
  * @param $object object An object.
  * @param $class string Class name.
  * @return bool True iff $object is a $class
@@ -1597,7 +1600,7 @@ function function_usable($function_name) {
  *
  * This is used for generating ETags.
  */
-function hash ($x) {
+function wikihash ($x) {
     if (is_scalar($x)) {
         return $x;
     }
@@ -1645,6 +1648,24 @@ function rand_ascii($length = 1) {
     return $s;
 }
 
+/* by Dan Frankowski.
+ */
+function rand_ascii_readable ($length = 6) {
+    // Pick a few random letters or numbers
+    $word = "";
+    better_srand();
+    // Don't use 1lI0O, because they're hard to read
+    $letters = "abcdefghijkmnopqrstuvwxyzABCDEFGHJKLMNPQRSTUVWXYZ23456789";
+    $letter_len = strlen($letters);
+    for ($i=0; $i < $length; $i++) {
+        if (function_exists('mt_rand'))
+            $word .= $letters[mt_rand(0, $letter_len-1)];
+        else
+            $word .= $letters[rand(0, $letter_len-1)];
+    }
+    return $word;
+}
+
 /**
  * Recursively count all non-empty elements 
  * in array of any dimension or mixed - i.e. 
@@ -1739,18 +1760,29 @@ class Alert {
 // 1.3.9-p1  => 1030.091
 // 1.3.10pre => 1030.099
 // 1.3.11pre-20041120 => 1030.1120041120
+// 1.3.12-rc1 => 1030.119
 function phpwiki_version() {
     static $PHPWIKI_VERSION;
     if (!isset($PHPWIKI_VERSION)) {
         $arr = explode('.',preg_replace('/\D+$/','', PHPWIKI_VERSION)); // remove the pre
         $arr[2] = preg_replace('/\.+/','.',preg_replace('/\D/','.',$arr[2]));
         $PHPWIKI_VERSION = $arr[0]*1000 + $arr[1]*10 + 0.01*$arr[2];
-        if (strstr(PHPWIKI_VERSION, 'pre'))
+        if (strstr(PHPWIKI_VERSION, 'pre') or strstr(PHPWIKI_VERSION, 'rc'))
             $PHPWIKI_VERSION -= 0.01;
     }
     return $PHPWIKI_VERSION;
 }
 
+function phpwiki_gzhandler($ob) {
+    if (function_exists('gzencode'))
+        $ob = gzencode($ob);
+        $GLOBALS['request']->_ob_get_length = strlen($ob);
+    if (!headers_sent()) {
+        header(sprintf("Content-Length: %d", $GLOBALS['request']->_ob_get_length));
+    }
+    return $ob;
+}
+
 function isWikiWord($word) {
     global $WikiNameRegexp;
     //or preg_match('/\A' . $WikiNameRegexp . '\z/', $word) ??
@@ -2010,15 +2042,22 @@ function getMemoryUsage() {
     } elseif (function_exists('getrusage') and ($u = getrusage()) and !empty($u['ru_maxrss'])) {
         $mem = $u['ru_maxrss'];
     } elseif (substr(PHP_OS,0,3) == 'WIN') { // requires a newer cygwin
-        // what we want is the process memory only: apache or php
+        // what we want is the process memory only: apache or php (if CGI)
         $pid = getmypid();
         $memstr = '';
-        // This works only if it's a cygwin process (apache or php)
-        //$memstr = exec("cat /proc/$pid/statm |cut -f1");
+	// win32_ps_stat_proc, win32_ps_stat_mem
+ 	if (function_exists('win32_ps_list_procs')) {
+	    $info = win32_ps_stat_proc($pid);
+	    $memstr = $info['mem']['working_set_size'];
+	} else {
+	    // This works only if it's a cygwin process (apache or php)
+	    // requires a newer cygwin
+	    //$memstr = exec("cat /proc/$pid/statm |cut -f1");
 
-        // if it's native windows use something like this: 
-        //   (requires pslist from sysinternals.com)
-        //$memstr = exec("pslist $pid|grep -A1 Mem|sed 1d|perl -ane\"print \$"."F[5]\"");
+	    // if it's native windows use something like this: 
+	    //   (requires pslist from sysinternals.com)
+	    //$memstr = exec("pslist $pid|grep -A1 Mem|sed 1d|perl -ane\"print \$"."F[5]\"");
+        }
         return (integer) trim($memstr);
     } elseif (1) {
         $pid = getmypid();
@@ -2033,6 +2072,21 @@ function getMemoryUsage() {
 }
 
 // $Log: stdlib.php,v $
+// Revision 1.249  2005/10/30 14:24:33  rurban
+// move rand_ascii_readable from Captcha to stdlib
+//
+// Revision 1.248  2005/10/29 14:18:30  uckelman
+// Added is_a() deprecation note.
+//
+// Revision 1.247  2005/10/10 20:31:21  rurban
+// fix win32ps call
+//
+// Revision 1.246  2005/10/10 19:38:48  rurban
+// add win32ps
+//
+// Revision 1.245  2005/09/18 16:01:09  rurban
+// trick to send the correct gzipped Content-Length
+//
 // Revision 1.244  2005/09/11 13:24:33  rurban
 // fix shortname, dont quote twice in ListRegexExpand
 //
