@@ -80,6 +80,8 @@ $locale["%s is empty"] =
    "%s ist leer";
 $locale["%s is empty."] =
    "%s ist leer.";
+$locale["%s is listed at %s"] =
+   "%s ist auf %s aufgelisted";
 $locale["%s is missing"] =
    "%s Argument fehlt";
 $locale["%s is not locked!"] =
@@ -332,6 +334,8 @@ $locale["Are you sure you want to permanently rename the selected files?"] =
    "Sind Sie sicher, da Sie die ausgewhlen Seiten wirklich umbenennen wollen?";
 $locale["Are you sure you want to permanently search & replace text in the selected files?"] =
    "Sind Sie sicher, da Sie alle Wrter in den angegebenen Seiten ersetzen wollen?";
+$locale["Argument '%s' not declared by plugin."] =
+   "Argument %s nicht im Zusatzprogramm deklariert.";
 $locale["Arguments"] =
    "Parameter";
 $locale["Attempting to use the directory '%s' instead."] =
@@ -432,8 +436,6 @@ $locale["Cannot open AUTH_GROUP_FILE %s"] =
    "Kann AUTH_GROUP_FILE %s nicht ffnen";
 $locale["Case insensitive?"] =
    "Gross/Kleinschreibung beachten?";
-$locale["Category"] =
-   "Kategorie";
 $locale["CategoryCategory"] =
    "KategorieKategorie";
 $locale["CategoryGroup"] =
@@ -462,7 +464,7 @@ $locale["Check any two boxes then %s."] =
    "Whlen Sie zwei Versionen aus, dann %s.";
 $locale["Check any two boxes to compare revisions."] =
    "Whlen Sie zwei Versionen zum Vergleich aus.";
-$locale["Check to add this Acl"] =
+$locale["Check to add this ACL"] =
    "Anklicken um diese ACL hinzuzufgen";
 $locale["Chmod"] =
    "Chmod";
@@ -766,6 +768,8 @@ $locale["File names may only contain alphanumeric characters and dot, underscore
    "Dateinamen drfen nur folgende Zeichen enthalten: alphanumerische Zeichen, Punkt, Unterstrich und Bindestrich.";
 $locale["File successfully uploaded."] =
    "Datei erfolgreich hochgeladen.";
+$locale["FileInfo"] =
+   "DateiInfo";
 $locale["Files with extension %s are not allowed."] =
    "Dateien mit der Endung %s sind nicht erlaubt.";
 $locale["FindPage"] =
@@ -1768,6 +1772,8 @@ $locale["Table Of Contents"] =
    "Inhaltsverzeichnis";
 $locale["TeX directory not writable."] =
    "Keine Schreibrechte fr das TeX Verzeichnis.";
+$locale["Template"] =
+   "Vorlage";
 $locale["TermsOfUse"] =
    "BenutzungsBedingungen";
 $locale["TextFormattingRules"] =
@@ -1878,8 +1884,6 @@ $locale["Top & bottom toolbars"] =
    "Obere u. untere Werkzeugleisten";
 $locale["Top Recommendations"] =
    "Beste Bewertungungen";
-$locale["Topic"] =
-   "Thema";
 $locale["Total %d plugins: "] =
    "%d Gesammte Zusatzprogramme: ";
 $locale["Total of %d languages: "] =
@@ -1912,10 +1916,14 @@ $locale["UNOBTAINABLE"] =
    "UNERREICHBAR";
 $locale["USER"] =
    "BENUTZER";
+$locale["Unable to bind LDAP server %s using %s %s"] =
+   "Konnte nicht LDAP Server %s verbinden. mit %s %s";
 $locale["Unable to connect to IMAP server "] =
    "IMAP Server nicht gefunden ";
 $locale["Unable to connect to LDAP server %s"] =
    "Konnte LDAP Server %s nicht finden";
+$locale["Unable to find src='%s'"] =
+   "Konnte src='%s' nicht lesen";
 $locale["Unable to load: %s"] =
    "Konnte %s nicht laden";
 $locale["Unable to open directory '%s' for reading"] =
@@ -2202,8 +2210,6 @@ $locale["add "] =
    "hinzufgen ";
 $locale["argument '%s' not declared by plugin"] =
    "Argument %s nicht im Zusatzprogramm deklariert";
-$locale["argument '%s' not declared by plugin."] =
-   "Argument %s nicht im Zusatzprogramm deklariert.";
 $locale["authenticated"] =
    "authentifizierten";
 $locale["blog"] =
@@ -2252,8 +2258,6 @@ $locale["current version"] =
    "aktuelle Version";
 $locale["days"] =
    "Tage";
-$locale["db type:"] =
-   "Dbtyp:";
 $locale["default page permission"] =
    "Vorgabe Zugriffsrecht";
 $locale["diff"] =
@@ -2294,6 +2298,8 @@ $locale["hours"] =
    "Stunden";
 $locale["invalid %s ignored"] =
    "ungltiges %s ignoriert";
+$locale["invalid argument %s"] =
+   "Ungltiger Parameter %s";
 $locale["invidual page permission"] =
    "individuelles Zugriffsrecht";
 $locale["latest comment by "] =
@@ -2392,8 +2398,6 @@ $locale["the file '%s'"] =
    "die Datei %s";
 $locale["the session.save_path directory '%s'"] =
    "das session.save_path Verzeichnis %s";
-$locale["timeout:"] =
-   "Zeitberschreitung:";
 $locale["to"] =
    "nach";
 $locale["today"] =
