@@ -236,8 +236,6 @@ $locale["ADMIN"] =
    "ADMIN";
 $locale["ANON"] =
    "ANONYME";
-$locale["AUTH_GROUP_FILE not defined"] =
-   "AUTH_GROUP_FILE non dfini";
 $locale["About"] =
    " propos de";
 $locale["Access"] =
@@ -330,6 +328,8 @@ $locale["Are you sure you want to permanently rename the selected files?"] =
    "tes-vous certain de renommer dfinitivement les pages slectionnes ?";
 $locale["Are you sure you want to permanently search & replace text in the selected files?"] =
    "Etes-vous sur de vouloir rechercher et remplacer dans les fichiers slectionnes ?";
+$locale["Argument '%s' not declared by plugin."] =
+   "argument '%s' non dclar par le plugin.";
 $locale["Arguments"] =
    "Arguments";
 $locale["Attempting to use the directory '%s' instead."] =
@@ -420,8 +420,6 @@ $locale["Cannot open AUTH_GROUP_FILE %s"] =
    "Impossible d'ouvrir AUTH_GROUP_FILE %s";
 $locale["Case insensitive?"] =
    "Sensible  la casse ?";
-$locale["Category"] =
-   "Catgorie";
 $locale["CategoryCategory"] =
    "CatgorieCatgorie";
 $locale["CategoryGroup"] =
@@ -446,7 +444,7 @@ $locale["Check any two boxes then %s."] =
    "Cochez une bote puis %s.";
 $locale["Check any two boxes to compare revisions."] =
    "Cochez une des botes pour comparer les rvisions.";
-$locale["Check to add this Acl"] =
+$locale["Check to add this ACL"] =
    "Vrifier pour ajouter cette ACL";
 $locale["Chmod"] =
    "Chmod";
@@ -754,6 +752,8 @@ $locale["Fatal PhpWiki Error"] =
    "Erreur Fatale de PhpWiki";
 $locale["File successfully uploaded."] =
    "Fichier transfr avec succs.";
+$locale["FileInfo"] =
+   "FichierInfo";
 $locale["Files with extension %s are not allowed."] =
    "%s: extension interdit.";
 $locale["FindPage"] =
@@ -946,8 +946,6 @@ $locale["JabberPresence"] =
    "JabberPresence";
 $locale["Keep up to %d major edits, but keep them no longer than %d days."] =
    "Garder jusqu' %d dition majeures, mais pas plus que %d jours.";
-$locale["LDAP_AUTH_HOST not defined"] =
-   "LDAP_AUTH_HOST non dfini";
 $locale["Language"] =
    "Langage";
 $locale["Last"] =
@@ -1656,8 +1654,6 @@ $locale["Sign Out"] =
    "Dconnexion";
 $locale["Sign in as:"] =
    "Se connecter en tant que :";
-$locale["Sign in:"] =
-   "S'enregistrer :";
 $locale["SignIn"] =
    "Connexion";
 $locale["SignOut"] =
@@ -1868,8 +1864,6 @@ $locale["Too many external links."] =
    "Trop de liens exterieurs.";
 $locale["Top & bottom toolbars"] =
    "Barres d'outils en haut et en bas";
-$locale["Topic"] =
-   "Sujet";
 $locale["Total %d plugins: "] =
    "%d plugins au total : ";
 $locale["Total of %d languages: "] =
@@ -1902,6 +1896,8 @@ $locale["UNOBTAINABLE"] =
    "INACCESSIBLE";
 $locale["USER"] =
    "UTILISATEUR";
+$locale["Unable to bind LDAP server %s using %s %s"] =
+   "Impossible de se connecter au serveur LDAP %s, avec %s %s";
 $locale["Unable to connect to IMAP server "] =
    "Impossible de se connecter au serveur IMAP ";
 $locale["Unable to connect to LDAP server %s"] =
@@ -1936,6 +1932,8 @@ $locale["Unlocking pages"] =
    "Dverrouiller les pages";
 $locale["Unsupported ACL access type %s ignored."] =
    "Le type d'accs ACL %s n'est pas support. -- Ignor.";
+$locale["Unsupported argument: %s=%s"] =
+   "Argument %s=%s n'est pas support !";
 $locale["Up"] =
    "Haut";
 $locale["UpLoad"] =
@@ -2194,8 +2192,6 @@ $locale["always skip the HomePage."] =
    "toujours ignorer la page d'accueil.";
 $locale["argument '%s' not declared by plugin"] =
    "argument '%s' non dclar par le plugin";
-$locale["argument '%s' not declared by plugin."] =
-   "argument '%s' non dclar par le plugin.";
 $locale["authenticated"] =
    "authentifi";
 $locale["blog"] =
@@ -2250,12 +2246,6 @@ $locale["current version"] =
    "version actuelle";
 $locale["days"] =
    "jours";
-$locale["db backend:"] =
-   "db backend:";
-$locale["db type:"] =
-   "type de bd :";
-$locale["dba handler:"] =
-   "gestionnaire dba:";
 $locale["default page permission"] =
    "Permission de page par dfaut";
 $locale["diff"] =
@@ -2264,8 +2254,6 @@ $locale["diff this page"] =
    "diff de cette page";
 $locale["download a zip dump from this wiki"] =
    "tlcharger une sauvegarde compresse de ce wiki";
-$locale["download an html zip dump from this wiki"] =
-   "tlcharger une sauvegarde HTML compresse de ce wiki";
 $locale["dump html pages"] =
    "rcupration des pages HTML";
 $locale["dump serial pages"] =
@@ -2292,6 +2280,8 @@ $locale["home page"] =
    "Page d'accueil";
 $locale["invalid %s ignored"] =
    "%s non valable ignor";
+$locale["invalid argument %s"] =
+   "Argument non valable %s";
 $locale["invidual page permission"] =
    "Permission de page individuelle";
 $locale["latest comment by "] =
@@ -2390,8 +2380,6 @@ $locale["the file '%s'"] =
    "le fichier %s";
 $locale["the session.save_path directory '%s'"] =
    "le rpertoire 'session.save_path' '%s'";
-$locale["timeout:"] =
-   "temps mort :";
 $locale["to"] =
    "";
 $locale["today"] =
