@@ -1638,12 +1638,6 @@ $locale["current version"] =
    "目前版本";
 $locale["days"] =
    "天";
-$locale["db backend:"] =
-   "db 後台:";
-$locale["db type:"] =
-   "db 型態:";
-$locale["dba handler:"] =
-   "dba handler:";
 $locale["default page permission"] =
    "預設頁面權限";
 $locale["diff"] =
@@ -1732,8 +1726,6 @@ $locale["stddev: %2.3f"] =
    "stddev: %2.3f";
 $locale["the file '%s'"] =
    "檔案 '%s'";
-$locale["timeout:"] =
-   "逾時:";
 $locale["to"] =
    "到";
 $locale["today"] =
