@@ -1,6 +1,6 @@
 <?php // #!/usr/local/bin/php -Cq
 /* Copyright (C) 2004 Dan Frankowski <dfrankow@cs.umn.edu>
- * Copyright (C) 2004 Reini Urban <rurban@x-ray.at>
+ * Copyright (C) 2004,2005,2006 Reini Urban <rurban@x-ray.at>
  *
  * This file is part of PhpWiki.
  * 
@@ -49,21 +49,28 @@
 // web: Mem29424 => Mem35400  (without USECACHE) (6MB)
 //define('USECACHE', false);
 
-####################################################################
-#
-# Preamble needed to get the tests to run.
-#
-####################################################################
+//##################################################################
+//
+// Preamble needed to get the tests to run.
+//
+//##################################################################
 
 $cur_dir = getcwd();
-# Add root dir to the path
+// Add root dir to the path
 if (substr(PHP_OS,0,3) == 'WIN')
     $cur_dir = str_replace("\\","/", $cur_dir);
 $rootdir = $cur_dir . '/../../';
 $ini_sep = substr(PHP_OS,0,3) == 'WIN' ? ';' : ':';
-$include_path = ini_get('include_path') . $ini_sep . $rootdir . $ini_sep . $rootdir . "lib/pear";
+$include_path = ini_get('include_path') . $ini_sep 
+              . $rootdir . $ini_sep . $rootdir . "lib/pear";
 ini_set('include_path', $include_path);
 define('DEFAULT_LANGUAGE','en'); // don't use browser detection
+$LANG='en';
+if (!isset($HTTP_SERVER_VARS)) {
+   $HTTP_SERVER_VARS =& $_SERVER;
+   $HTTP_GET_VARS    =& $_GET;
+   $HTTP_POST_VARS   =& $_POST;
+}
 
 if (!empty($HTTP_SERVER_VARS) and $HTTP_SERVER_VARS["SERVER_NAME"] == 'phpwiki.sourceforge.net') {
     ini_set('include_path', ini_get('include_path') . ":/usr/share/pear");
@@ -76,10 +83,21 @@ if (!empty($HTTP_SERVER_VARS) and $HTTP_SERVER_VARS["SERVER_NAME"] == 'phpwiki.s
 $database_backends = array(
                            'file',
                            'dba',
-                           'SQL',
-                           'ADODB',
+                           'SQL',   // default backend defined in the config.ini DSN
+                           'ADODB', // same backend as defined in the config.ini DSN
+			   // specific backends (need to be setup as db=test_phpwiki)
+			   'PearDB_pgsql', 'PearDB_sqlite', 'PearDB_mysql',
+			   //'PearDB_oci8','PearDB_mssql', 
+			   'ADODB_postgres7', 'ADODB_sqlite', 'ADODB_mysql', 
+			   //'ADODB_oci8', 'ADODB_mssql', 
+                           // 'cvs'
                            );
+if ((int)substr(phpversion(), 1) >= 5)
+    array_push($database_backends, 'PDO_pqsql', 'PDO_sqlite', 'PDO_mysql');
+                                   //'PDO_oci', 'PDO_odbc'
+
 //TODO: convert cvs test                           
+// For "cvs" see the seperate tests/unit_test_backend_cvs.php (cvs is experimental)
 //TODO: read some database values from config.ini, just use the "test_" prefix
 // "flatfile" testing occurs in "tests/unit/.testbox/"
 // "dba" needs the DATABASE_DBA_HANDLER, also in the .textbox directory
@@ -88,9 +106,8 @@ $database_backends = array(
 //  You have to create that database beforehand with our schema
 //$database_dsn = "mysql://wikiuser:@localhost/phpwiki";
 $database_prefix = "test_";
-// For "cvs" see the seperate tests/unit_test_backend_cvs.php (cvs is experimental)
 
-# Quiet warnings in IniConfig.php
+// Quiet warnings in IniConfig.php
 $HTTP_SERVER_VARS['REMOTE_ADDR'] = '127.0.0.1';
 $HTTP_SERVER_VARS['HTTP_USER_AGENT'] = "PHPUnit";
 
@@ -123,7 +140,7 @@ function printSimpleTrace($bt) {
     }
 }
 */
-# Show lots of detail when an assert() in the code fails
+// Show lots of detail when an assert() in the code fails
 function assert_callback( $script, $line, $message ) {
    echo "assert failed: script ", $script," line ", $line," :";
    echo "$message";
@@ -135,9 +152,9 @@ function assert_callback( $script, $line, $message ) {
 }
 $foo = assert_options( ASSERT_CALLBACK, 'assert_callback');
 
-#
-# Get error reporting to call back, too
-#
+//
+// Get error reporting to call back, too
+//
 // set the error reporting level for this script
 if (defined('E_STRICT') and (E_ALL & E_STRICT)) // strict php5?
     error_reporting(E_ALL & ~E_STRICT); 	// exclude E_STRICT
@@ -194,6 +211,7 @@ function purge_testbox() {
         break;
     case 'SQL':
     case 'ADODB':
+    case 'PDO':
         foreach ($dbi->_backend->_table_names as $table) {
             $dbi->genericSqlQuery("DELETE FROM $table");
         }
@@ -278,8 +296,11 @@ function updateLevelEdit(formObj) {
    }
 }");
     $option = HTML::div(array('class' => 'option'),
-                        HTML::span(array('style'=>'font-weight: bold','onDblClick'=>'flipAll(\'_debug[\')'), 'debug: '),
-                        HTML::input(array('name'=>'debug','id'=>'debug','value'=>$debug_level,'size'=>5)),
+                        HTML::span(array('style'=>'font-weight: bold',
+                                         'onDblClick'=>'flipAll(\'_debug[\')'), 
+                                   'debug: '),
+                        HTML::input(array('name'=>'debug','id'=>'debug',
+                                          'value'=>$debug_level,'size'=>5)),
                         HTML::br());
     foreach (array('VERBOSE' 	=> 1,
                    'PAGELINKS' 	=> 2,
@@ -299,7 +320,8 @@ function updateLevelEdit(formObj) {
 
     $option = HTML::div(array('class' => 'option'), 
                         HTML::span(array('style'=>'font-weight: bold'), "level: "),
-                        HTML::input(array('name'=>'level','id'=>'level','value'=>$user_level,'size'=>5)),
+                        HTML::input(array('name'=>'level','id'=>'level',
+                                          'value'=>$user_level,'size'=>5)),
                         HTML::br());
     foreach (array('FORBIDDEN' 	=> -1,
                    'ANON' 	=> 0,
@@ -338,11 +360,11 @@ function updateLevelEdit(formObj) {
     return $table->printXml();
 }
 
-####################################################################
-#
-# End of preamble, run the test suite ..
-#
-####################################################################
+//####################################################################
+//
+// End of preamble, run the test suite ..
+//
+//####################################################################
 
 ob_start();
 
@@ -362,7 +384,9 @@ $user_level  = 1; // BOGO (conflicts with RateIt)
 $alltests = array('InlineParserTest','HtmlParserTest',
                   'PageListTest','ListPagesTest',
                   'SetupWiki',
-                  'AllPagesTest','AllUsersTest','OrphanedPagesTest','WantedPagesTest','TextSearchTest',
+                  'AllPagesTest','AllUsersTest','OrphanedPagesTest',
+                  'WantedPagesTest',
+                  'TextSearchTest','IncludePageTest',
                   'DumpHtml');
 // support db=file db=dba test=SetupWiki test=DumpHtml debug=num -dconstant=value
 // or  db=file,dba test=SetupWiki,DumpHtml debug=num -dconstant=value
@@ -383,6 +407,7 @@ if (!empty($argv)) {
     $runtests = array();
     $define = array();
     $run_database_backends = array();
+    $m = array();
     foreach ($argv as $arg) {
         if (preg_match("/^test=(.+)$/",$arg,$m) and in_array($m[1], $alltests))
             $runtests[] = $m[1];
@@ -442,7 +467,7 @@ if (DEBUG & 8)
     printMemoryUsage("beforePhpWiki");
 
 define('PHPWIKI_NOMAIN', true);
-# Other needed files
+// Other needed files
 require_once $rootdir.'index.php';
 require_once $rootdir.'lib/main.php';
 
@@ -455,10 +480,12 @@ ob_end_flush();
 
 if ($debug_level & 1) {
     //echo "\n";
-    echo "PHPWIKI_VERSION=",PHPWIKI_VERSION, strstr(PHPWIKI_VERSION,"pre") ? strftime(" / %Y%m%d") : "","\n";
+    echo "PHPWIKI_VERSION=",PHPWIKI_VERSION, 
+        strstr(PHPWIKI_VERSION,"pre") ? strftime(" / %Y%m%d") : "","\n";
     if ($debug_level & 9) {
         // which constants affect memory?
-        foreach (explode(",","USECACHE,WIKIDB_NOCACHE_MARKUP,ENABLE_USER_NEW,ENABLE_PAGEPERM") as $v) {
+        foreach (explode(",","USECACHE,WIKIDB_NOCACHE_MARKUP,"
+                            ."ENABLE_USER_NEW,ENABLE_PAGEPERM") as $v) {
             printConstant($v);
         }
     }
@@ -467,9 +494,9 @@ if ($debug_level & 1) {
 
 global $ErrorManager;
 $ErrorManager->setPostponedErrorMask(EM_FATAL_ERRORS|EM_WARNING_ERRORS|EM_NOTICE_ERRORS);
-//FIXME: ignore cached requests (if-modified-since) from cli
+// FIXME: ignore cached requests (if-modified-since) from cli
 class MockRequest extends WikiRequest {
-    function MockRequest(&$dbparams) {
+    function MockRequest($dbparams) {
         $this->_dbi = WikiDB::open($dbparams);
         $this->_user = new MockUser("a_user", $GLOBALS['user_level']);
         $this->_group = new GroupNone();
@@ -516,19 +543,20 @@ else {
     $request->_prefs = $request->_user->getPreferences();
 }
 */
-include_once("themes/" . THEME . "/themeinfo.php");
 if (DEBUG & _DEBUG_TRACE)
     printMemoryUsage("PhpWikiLoaded");
 
 // provide a nice input form for all options
 if (isset($HTTP_SERVER_VARS['REQUEST_METHOD'])) {
     echo html_option_form();
+    flush();
 }
 
 // save and restore all args for each test.
 class phpwiki_TestCase extends PHPUnit_TestCase {
     function setUp() { 
-        global $request;
+        global $request, $WikiTheme;
+	include_once("themes/" . THEME . "/themeinfo.php");
         $this->_savedargs = $request->_args;
         $request->_args = array();
         if (DEBUG & 1) {
@@ -544,19 +572,34 @@ class phpwiki_TestCase extends PHPUnit_TestCase {
     }
 }
 
-# Test all db backends.
+// Test all db backends.
 foreach ($run_database_backends as $dbtype) {
+    global $request, $DBParams;
     //    if (DEBUG & _DEBUG_TRACE)
     //        printMemoryUsage("PHPUnitInitialized");
-
-    $DBParams['dbtype']               = $dbtype;
+    $DBParams['dbtype'] = $dbtype;
+    if (string_starts_with($dbtype, 'PearDB_')) {
+	$DBParams['dbtype'] = 'SQL';
+	$DBParams['dsn'] = preg_replace("/^([^:]+):/", substr($dbtype, 7).":", $DBParams['dsn']);
+        echo "dsn: ",$DBParams['dsn'],"\n";
+    }
+    if (string_starts_with($dbtype, 'ADODB_')) {
+	$DBParams['dbtype'] = 'ADODB';
+	$DBParams['dsn'] = preg_replace("/^([^:]+):/", substr($dbtype, 6).":", $DBParams['dsn']);
+        echo "dsn: ",$DBParams['dsn'],"\n";
+    }
+    if (string_starts_with($dbtype, 'PDO_')) {
+	$DBParams['dbtype'] = 'PDO';
+	$DBParams['dsn'] = preg_replace("/^([^:]+):/", substr($dbtype, 4).":", $DBParams['dsn']);
+        echo "dsn: ",$DBParams['dsn'],"\n";
+    }
     $DBParams['directory']            = $cur_dir . '/.testbox';
     $DBParams['prefix']               = $database_prefix;
     // from config.ini
-    //$DBParams['dsn']                  = $database_dsn;
     //$DBParams['dba_handler']          = $database_dba_handler;
 
     echo "Testing DB Backend \"$dbtype\" ...\n";
+    flush();
     $request = new MockRequest($DBParams);
     if ( ! ENABLE_USER_NEW ) {
         $request->_user->_request =& $request;
